@@ -19,15 +19,27 @@ call.
 
 #include <signal.h>
 #include "sipomatic.h"
+#include <eXosip.h>
 
 
 int run_cond=1;
 
 Sipomatic sipomatic;
 
+int sipomatic_accept_audio_offer(sdp_context_t *ctx,sdp_payload_t *payload);
+
+sdp_handler_t sipomatic_sdp_handler={
+	sipomatic_accept_audio_offer,   /*from remote sdp */
+	NULL,
+	NULL,
+	NULL,
+	NULL,
+	NULL,
+};
+
 static char *num2str(int a)
 {
-	char *p=smalloc(10);
+	char *p=osip_malloc(10);
 	snprintf(p,10,"%i",a);
 	return p;
 }
@@ -38,41 +50,31 @@ void stop_handler(int signum)
 	run_cond=0;
 }
 
-int invite_accepted_cb(OsipDialog *call,transaction_t *trn, sip_t *msg,void *p2)
+void sipomatic_process_event(Sipomatic *obj,eXosip_event_t *ev)
 {
-	/* we should never be here since sipomatic is unable to to make invites*/
-	return(0);
-}
-
-int bye_cb(OsipDialog *dialog,transaction_t *trn, sip_t *msg,void *p2)
-{
-	/* get the call */
-	Call *call=(Call*)dialog->data;
-	sipomatic_lock(&sipomatic);
-	if ( sipomatic_check_call(&sipomatic,call))
-		call->state=CALL_STATE_FINISHED;
-	sipomatic_unlock(&sipomatic);
-	return(0);
-}
-
-int invite_cb(OsipDialog *dialog,transaction_t *trn, sip_t *sipmsg,void *p2)
-{
-	/* we have just received an invite, so wait two seconds, then accept it*/
-	char *p;
 	Call *call;
-	
-	from_2char(sipmsg->from,&p);
-	g_message("Contacted by %s.\n",p);
-	sfree(p);
-	call=call_new(dialog);
-	call->current_trn=trn;
-	call->root=&sipomatic;
-	sipomatic_lock(&sipomatic);
-	sipomatic.calls=g_list_append(sipomatic.calls,call);
-	sipomatic_unlock(&sipomatic);
-	return(0);
+	switch(ev->type){
+		case EXOSIP_CALL_NEW:
+			call_new(obj,ev->did,ev->sdp_body);
+			break;
+		case EXOSIP_CALL_CLOSED:
+		case EXOSIP_CALL_CANCELLED:
+			call=sipomatic_find_call(obj,ev->did);
+			if (call==NULL){
+				g_warning("Could not find call with did %i !",ev->did);
+			}
+			call_release(call);
+			call_destroy(call);
+			break;
+		case EXOSIP_IN_SUBSCRIPTION_NEW:
+			g_message("Receving new incoming subscription.");
+			eXosip_notify_accept_subscribe(ev->did,200,EXOSIP_SUBCRSTATE_ACTIVE,EXOSIP_NOTIFY_ONLINE);
+			break;
+	}
+	eXosip_event_free(ev);
 }
 
+
 gint endoffile_cb(MSFilter *f,gint ev,gpointer arg,gpointer data)
 {
 	Call*call=(Call*)data;
@@ -81,50 +83,33 @@ gint endoffile_cb(MSFilter *f,gint ev,gpointer arg,gpointer data)
 
 void call_accept(Call *call)
 {
-	SdpContext *ctx;
+	sdp_context_t *ctx;
 	int status;
-	OsipDialog *dialog=call->dialog;
-	CallParams *callparams;
 	PayloadType *payload;
 	gchar *hellofile;
 	
-	ctx=SDP_CONTEXT(osip_dialog_get_body_context(dialog,"application/sdp",0));
-	callparams=(CallParams*)BODY_CONTEXT(ctx)->data;
-	status=sdp_context_get_negociation_status(ctx);
-	if (status!=200){
-		g_message("Error during sdp negociation, cannot accept call.\n");
-		osip_dialog_respond(dialog,call->current_trn,SDP_CONTEXT(ctx)->negoc_status);
-		call->state=CALL_STATE_FINISHED;
-		return;
-	}
-	payload=rtp_profile_get_payload(callparams->profile,callparams->pt);
+	ctx=call->sdpc;
+	payload=rtp_profile_get_payload(call->profile,call->pt);
 	if (strcmp(payload->mime_type,"telephone-event")==0){
 		/* telephone-event is not enough to accept a call */
 		g_message("Cannot accept call with only telephone-event.\n");
-		osip_dialog_respond(dialog,call->current_trn,415);
+		eXosip_answer_call(call->did,415,NULL);
 		call->state=CALL_STATE_FINISHED;
 		return;
 	}
 	if (payload->clock_rate==16000){
 		hellofile=call->root->file_path16000hz;
 	}else hellofile=call->root->file_path8000hz;
-	osip_dialog_accept_invite(dialog,call->current_trn);
- 	call->audio_stream=audio_stream_start_with_files(callparams->profile,callparams->localport,
-				callparams->remaddr,callparams->remoteport,callparams->pt,20,hellofile,"/dev/null",NULL);
+	eXosip_answer_call_with_body(call->did,200,"application/sdp",call->sdpc->answerstr);
+ 	call->audio_stream=audio_stream_start_with_files(call->profile,call->localport,
+				call->remaddr,call->remoteport,call->pt,20,hellofile,"/dev/null");
 	g_timer_reset(call->timer);
 	call->state=CALL_STATE_RUNNING;
-	call->params=callparams;
 	ms_filter_set_notify_func(call->audio_stream->soundread,endoffile_cb,(gpointer)call);
 }
 
 
-int faillure_cb(OsipDialog *call,transaction_t *trn, sip_t *msg,void *p2)
-{
-	return(0);
-}
-
-
-int payload_is_supported(SdpPayload *payload,RtpProfile *local_profile,RtpProfile *dialog_profile)
+PayloadType * sipomatic_payload_is_supported(sdp_payload_t *payload,RtpProfile *local_profile,RtpProfile *dialog_profile)
 {
 	int localpt;
 	if (payload->a_rtpmap!=NULL){
@@ -135,51 +120,51 @@ int payload_is_supported(SdpPayload *payload,RtpProfile *local_profile,RtpProfil
 	}
 	
 	if (localpt>=0){
-
+		MSCodecInfo *info;
 		/* this payload is supported in our local rtp profile, so add it to the dialog rtp
 		profile */
 		PayloadType *rtppayload;
 		rtppayload=rtp_profile_get_payload(local_profile,localpt);
-		if (rtppayload==NULL) return 0;
+		if (rtppayload==NULL) return NULL;
+		/*check if we have the appropriate coder/decoder for this payload */
+		if (strcmp(rtppayload->mime_type,"telephone-event")==0) return rtppayload;
+		info=ms_audio_codec_info_get(rtppayload->mime_type);
+		if (info==NULL) return NULL;
 		rtppayload=payload_type_clone(rtppayload);
 		rtp_profile_set_payload(dialog_profile,payload->pt,rtppayload);
 		/* add to the rtp payload type some other parameters (bandwidth) */
 		if (payload->b_as_bandwidth!=0) rtppayload->normal_bitrate=payload->b_as_bandwidth*1000;
-		return 1;
+		return rtppayload;
+		
 	}
-	return 0;
+	return NULL;
 }
-int accept_audio_offer(SdpHandler *sdph,SdpContext *ctx,SdpPayload *payload)
+int sipomatic_accept_audio_offer(sdp_context_t *ctx,sdp_payload_t *payload)
 {
 	static int audioport=8000;
-	OsipDialog *dialog=BODY_CONTEXT(ctx)->dialog;
-	CallParams *callparams;
-	int supported;
-	if (BODY_CONTEXT(ctx)->data!=NULL){
-		callparams=(CallParams *) BODY_CONTEXT(ctx)->data;
-	}else{
-		callparams=call_params_new();
-		BODY_CONTEXT(ctx)->data=(void*)callparams;
-	}
+	Call *call=(Call*)sdp_context_get_user_pointer(ctx);
+	PayloadType *supported;
+	
 	
 	/* see if this codec is supported in our local rtp profile*/
-	supported=payload_is_supported(payload,&av_profile,callparams->profile);
-	if (!supported) {
+	supported=sipomatic_payload_is_supported(payload,&av_profile,call->profile);
+	if (supported==NULL) {
 		g_message("Refusing codec %i (%s)",payload->pt,payload->a_rtpmap);
 		return -1;
 	}
-	if (callparams->ncodecs==0){
+	if (strcmp(supported->mime_type,"telephone-event")==0) return 0;
+	if (call->ncodecs==0 ){
 		/* this is the first codec we may accept*/
-		callparams->localport=payload->localport=audioport;
-		callparams->remoteport=payload->remoteport;
-		callparams->line=payload->line;
-		callparams->pt=payload->pt; /* remember the first payload accepted */
-		callparams->remaddr=payload->c_addr;
-		callparams->ncodecs++;
+		call->localport=payload->localport=audioport;
+		call->remoteport=payload->remoteport;
+		call->line=payload->line;
+		call->pt=payload->pt; /* remember the first payload accepted */
+		call->remaddr=payload->c_addr;
+		call->ncodecs++;
 		audioport+=4;
 	}else{
 		/* refuse all other audio lines*/
-		if(callparams->line!=payload->line) return -1;
+		if(call->line!=payload->line) return -1;
 	}
 	return 0;
 }
@@ -188,49 +173,60 @@ void sipomatic_init(Sipomatic *obj, gchar *url)
 {
 	MSCodecInfo *info;
 	GList *elem;
-	BodyHandler *sdph;
+	osip_uri_t *uri=NULL;
+	int port=5064;
 	if (url==NULL){
 		url=getenv("SIPOMATIC_URL");
-		if (url==NULL) url="sip:robot@0.0.0.0:5064";
+		if (url==NULL) url="sip:robot@127.0.0.1:5064";
+	}
+	if (url!=NULL) {
+		osip_uri_init(&uri);
+		if (osip_uri_parse(uri,url)==0){
+			if (uri->port!=NULL) port=atoi(uri->port);
+		}else{
+			g_warning("Invalid identity uri:%s",url);
+		}	
 	}
 	g_message("Starting using url %s",url);
-	obj->audio_codecs=ms_codec_get_all_audio();
 	obj->lock=g_mutex_new();
 	obj->calls=NULL;
 	obj->acceptance_time=5;
 	obj->max_call_time=300;
 	obj->file_path8000hz=g_strdup_printf("%s/%s",PACKAGE_SOUND_DIR,ANNOUCE_FILE8000HZ);
 	obj->file_path16000hz=g_strdup_printf("%s/%s",PACKAGE_SOUND_DIR,ANNOUCE_FILE16000HZ);
-	
-	/* create a user agent */
-	obj->ua=osip_ua_new();
-	osip_ua_set_contact(obj->ua,url);
-	osip_ua_signal_connect(obj->ua,"INVITE_ACCEPTED",invite_accepted_cb);
-  	osip_ua_signal_connect(obj->ua,"BYE",bye_cb);
-  	osip_ua_signal_connect(obj->ua,"FAILLURE",faillure_cb);
-  	osip_ua_signal_connect(obj->ua,"INVITE",invite_cb);
-	/* add sdp capabilities to the user agent */
-	sdph=sdp_handler_new();
-	sdp_handler_set_write_offer_fcn(SDP_HANDLER(sdph),NULL,NULL);
-	sdp_handler_set_accept_offer_fcn(SDP_HANDLER(sdph),accept_audio_offer,NULL);
-	sdp_handler_set_read_answer_fcn(SDP_HANDLER(sdph),NULL,NULL);
-	
-	osip_ua_add_body_handler(obj->ua,sdph);
-	
+	osip_trace_initialize(OSIP_INFO1,stdout);
+	osip_trace_initialize(OSIP_INFO2,stdout);
+	osip_trace_initialize(OSIP_WARNING,stdout);
+	osip_trace_initialize(OSIP_ERROR,stdout);
+	osip_trace_initialize(OSIP_BUG,stdout);
+	osip_trace_initialize(OSIP_FATAL,stdout);
+	osip_trace_enable_level(OSIP_INFO1);
+	osip_trace_enable_level(OSIP_INFO2);
+	osip_trace_enable_level(OSIP_WARNING);
+	osip_trace_enable_level(OSIP_ERROR);
+	osip_trace_enable_level(OSIP_BUG);
+	osip_trace_enable_level(OSIP_FATAL);
+	eXosip_init(NULL,stdout,port);
+	eXosip_set_user_agent("sipomatic-" LINPHONE_VERSION "/eXosip");
 }
 
 void sipomatic_uninit(Sipomatic *obj)
 {
 	g_mutex_free(obj->lock);
-	osip_ua_destroy(obj->ua);
+	eXosip_quit();
 }
 
 void sipomatic_iterate(Sipomatic *obj)
 {
 	GList *elem;
+	GList *to_be_destroyed=NULL;
 	Call *call;
 	gdouble time;
-	sipomatic_lock(obj);
+	eXosip_event_t *ev;
+
+	while((ev=eXosip_event_wait(0,0))!=NULL){
+		sipomatic_process_event(obj,ev);
+	}
 	elem=obj->calls;
 	while(elem!=NULL){
 		call=(Call*)elem->data;
@@ -244,65 +240,76 @@ void sipomatic_iterate(Sipomatic *obj)
 			case CALL_STATE_RUNNING:
 				if (time>obj->max_call_time || call->eof){
 					call_release(call);
-					elem=obj->calls=g_list_remove(obj->calls,call);
-					call_destroy(call);
+					to_be_destroyed=g_list_append(to_be_destroyed,call);
 				}
 			break;
-			case CALL_STATE_FINISHED:
-				elem=obj->calls=g_list_remove(obj->calls,call);
-				call_destroy(call);
-			break;
 		}
 		elem=g_list_next(elem);
 	}
-	sipomatic_unlock(obj);
+	for(;to_be_destroyed!=NULL; to_be_destroyed=g_list_next(to_be_destroyed)){
+		call_destroy((Call*)to_be_destroyed->data);
+	}
 }
 
-CallParams * call_params_new(){
-	CallParams *obj;
-	obj=g_new0(CallParams,1);
-	obj->profile=rtp_profile_new("remote");
-	return obj;
-}
-void call_params_destroy(CallParams *obj)
-{
-	rtp_profile_destroy(obj->profile);
-	g_free(obj);
-}
 
-gboolean sipomatic_check_call(Sipomatic *obj,Call *call)
+Call* sipomatic_find_call(Sipomatic *obj,int did)
 {
 	GList *it;
+	Call *call=NULL;
 	for (it=obj->calls;it!=NULL;it=g_list_next(it)){
-		if ( ((Call*)it->data)==call) return 1;
+		call=(Call*)it->data;
+		if ( call->did==did) return call;
 	}
-	return 0;
+	return call;
 }
 
-Call * call_new(OsipDialog *dialog)
+
+Call * call_new(Sipomatic *root, int did, char *sdp)
 {
-	Call *obj=g_new0(Call,1);
+	Call *obj;
+	char *sdpans;
+	int status;
+	sdp_context_t *sdpc=sdp_handler_create_context(&sipomatic_sdp_handler,NULL,"sipomatic");
+	obj=g_new0(Call,1);
+	obj->profile=rtp_profile_new("remote");
+	eXosip_answer_call(did,100,NULL);
+	sdp_context_set_user_pointer(sdpc,obj);
+	sdpans=sdp_context_get_answer(sdpc,sdp);
+	if (sdpans!=NULL){
+		eXosip_answer_call(did,180,NULL);
+		
+	}else{
+		status=sdp_context_get_status(sdpc);
+		eXosip_answer_call(did,status,NULL);
+		sdp_context_free(sdpc);
+		rtp_profile_destroy(obj->profile);
+		g_free(obj);
+	}
+	obj->sdpc=sdpc;
 	obj->timer=g_timer_new();
-	obj->dialog=dialog;
-	dialog->data=(void*)obj;
+	obj->did=did;
 	g_timer_start(obj->timer);
 	obj->audio_stream=NULL;
 	obj->state=CALL_STATE_INIT;
 	obj->eof=0;
+	obj->root=root;
+	root->calls=g_list_append(root->calls,obj);
 	return obj;
 }
 
 void call_release(Call *call)
 {
-	osip_dialog_bye(call->dialog);
+	eXosip_terminate_call(0,call->did);
+	if (call->audio_stream!=NULL) audio_stream_stop(call->audio_stream);
 	call->state=CALL_STATE_FINISHED;
 }
 
 void call_destroy(Call *obj)
 {
-	if (obj->audio_stream!=NULL) audio_stream_stop(obj->audio_stream);
+	obj->root->calls=g_list_remove(obj->root->calls,(gpointer)obj);
+	rtp_profile_destroy(obj->profile);
 	g_timer_destroy(obj->timer);
-	if (obj->params!=NULL) call_params_destroy(obj->params);
+	sdp_context_free(obj->sdpc);
 	g_free(obj);
 }
 
@@ -314,7 +321,6 @@ void sipomatic_set_annouce_file(Sipomatic *obj, char *file)
 	obj->file_path8000hz=g_strdup(file);
 }
 
-extern OsipManager *def_manager;
 
 void display_help()
 {
@@ -323,7 +329,7 @@ void display_help()
 			"sipomatic -v or --version: display version information.\n"
 			"	-u sip-url : specify the sip url sipomatic listens and answers.\n"
 			"	-f annouce-file : set the annouce file (16 bit raw format,8000Hz)\n"
-			"	-s port	: set the port sipomatic uses to send its SIP answers.\n");
+			" -6 enable ipv6 network usage\n");
 	exit(0);
 }
 
@@ -368,6 +374,10 @@ int main(int argc, char *argv[])
 			file=getarg(argc,argv,i);
 			continue;
 		}
+		if (strcmp(argv[i],"-6")==0){
+			eXosip_enable_ipv6(TRUE);
+			continue;
+		}
 	}
 	
 	signal(SIGINT,stop_handler);
@@ -379,10 +389,8 @@ int main(int argc, char *argv[])
 	rtp_profile_set_payload(&av_profile,110,&speex_nb);
 	rtp_profile_set_payload(&av_profile,111,&speex_wb);
 	rtp_profile_set_payload(&av_profile,101,&telephone_event);
- 	rtp_profile_set_payload(&av_profile,116,&truespeech);
-	TRACE_INITIALIZE(TRACE_LEVEL6,stdout);
-	osipua_init();
-	osip_manager_set_send_port(def_manager,sendport);
+    rtp_profile_set_payload(&av_profile,116,&truespeech);
+	
 	sipomatic_init(&sipomatic,url);
 	if (file!=NULL) sipomatic_set_annouce_file(&sipomatic,file);
 	
