@@ -20,13 +20,13 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 #include "misc.h"
 #include <mscodec.h>
-#include <regctxt.h>
 #include <stdlib.h>
 #include <stdio.h>
 #include <signal.h>
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <unistd.h>
+#include <fcntl.h>
 
 #ifdef INET6
 #include <sys/socket.h>
@@ -154,118 +154,6 @@ void restore_sound_daemons()
 	}
 }
 
-int linphone_core_set_alias(LinphoneCore *lc)
-{
-	char *contact=NULL;
-	char *user,*domain;
-	
-	if (lc->ua==NULL) return(-EFAULT);
-	
-	user=lc->sip_conf.username;
- 	domain=lc->sip_conf.hostname;
- 	
-#ifdef INET6
-	switch (lc->ua->ua_family) {
-	case AF_INET:
-	  if (lc->sip_conf.sip_port == 5060)
-		contact=g_strdup_printf("sip:%s@%s",user,domain);	
-	  else contact=g_strdup_printf("sip:%s@%s:%i",user,domain,lc->sip_conf.sip_port);
-	  break;
-	case AF_INET6:
-	  if (lc->sip_conf.sip_port == 5060)
-		contact=g_strdup_printf("sip:%s@[%s]",user,domain);	
-	  else contact=g_strdup_printf("sip:%s@[%s]:%i",user,domain,lc->sip_conf.sip_port);
-	  break;	  
-	default:
-	  g_error("Bad inet address family: %i !",lc->ua->ua_family);
-	  break;
-	}
-#else
-	if (lc->sip_conf.sip_port==5060)
-		contact=g_strdup_printf("sip:%s@%s",user,domain);	
-	else contact=g_strdup_printf("sip:%s@%s:%i",user,domain,lc->sip_conf.sip_port);
-#endif
-	//g_message("Adding %s to the list of alias.\n",contact);
-	g_return_val_if_fail(contact!=NULL,-1);
-	osip_ua_add_alias(lc->ua,contact);
-	if (lc->sip_conf.contact!=NULL) g_free(lc->sip_conf.contact);
-	lc->sip_conf.contact=contact;
-	return 0;
-}
-
-int linphone_core_update_contact_info(LinphoneCore *lc)
-{
-	int len;
-	char *prim_contact;
-#ifdef LINPHONE_DEPRECATED
-#ifdef INET6
-	len=32+strlen(lc->sip_conf.username) + 2;
-	prim_contact=g_malloc(len);
-	switch (lc->net_conf.sel_if->family){
-	case AF_INET:
-	  if (lc->sip_conf.sip_port == 5060)
-	    snprintf(prim_contact,len,"sip:%s@0.0.0.0",lc->sip_conf.username);
-	  else
-	    snprintf(prim_contact,len,"sip:%s@0.0.0.0:%i",lc->sip_conf.username,lc->sip_conf.sip_port);
-	  break;
-	case AF_INET6:
-	  if (lc->sip_conf.sip_port == 5060)
-	    snprintf(prim_contact,len,"sip:%s@[::0]",lc->sip_conf.username);
-	  else
-	    snprintf(prim_contact,len,"sip:%s@[::0]:%i",lc->sip_conf.username,lc->sip_conf.sip_port);
-	  break;
-	defaut:
-	  printf("invalid family type!!!\n");
-	  break;
-	}
-#else
-	len=strlen(lc->net_conf.sel_if->ip4addr)+12+strlen(lc->sip_conf.username);
-	prim_contact=g_malloc(len);
-	if (lc->sip_conf.sip_port==5060)
-		snprintf(prim_contact,len,"sip:%s@0.0.0.0",lc->sip_conf.username);
-	else 
-		snprintf(prim_contact,len,"sip:%s@0.0.0.0:%i",lc->sip_conf.username,lc->sip_conf.sip_port);
-#endif
-#endif
-	if (lc->sip_conf.sip_port==5060)
-		prim_contact=g_strdup_printf("sip:%s@0.0.0.0",lc->sip_conf.username);
-	else prim_contact=g_strdup_printf("sip:%s@0.0.0.0:%i",lc->sip_conf.username,lc->sip_conf.sip_port);
-	if (lc->net_conf.use_nat) linphone_core_set_nat_address(lc,lc->net_conf.nat_address,1);
-	else osip_ua_set_contact(lc->ua,prim_contact);
-	g_free(prim_contact);
-	linphone_core_set_alias(lc);
-}
-
-/* send a REGISTER request to the default registrar*/
-/* if doit is 0, then unregistration is done (expires is set to zero) */
-gint do_registration(LinphoneCore *lc,gboolean doit)
-{
-	static RegistrationCtxt *regctx=NULL;
-	
-	if (lc->sip_conf.reg_conf.registrar==NULL) return;
-	{
-		OsipDialog *call=osip_dialog_new(lc->ua);
-		if (regctx!=NULL) registration_ctxt_destroy(regctx);
-		regctx=registration_ctxt_new();		
-		registration_ctxt_set_registrar(regctx,lc->sip_conf.reg_conf.registrar);
-		registration_ctxt_set_password(regctx, lc->sip_conf.reg_conf.passwd);
-		registration_ctxt_set_address_of_record(regctx, lc->sip_conf.reg_conf.addr_of_rec);
-		if (doit) {
-			lc->vtable.display_status(lc,_("Registering..."));
-			registration_ctxt_set_expires(regctx,lc->sip_conf.reg_conf.expires);
-		}else {
-			registration_ctxt_set_expires(regctx,0);
-			//lc->vtable.display_status(lc,_("Unregistering..."));
-		}
-		
-		g_timer_reset(lc->sip_conf.reg_conf.timer);
-		osip_dialog_register(call,regctx);
-		/* we don't want more from the dialog:*/
-		osip_dialog_release(call);
-		g_message("Registration sent.\n");
-	}
-	return TRUE;
-}
 
 /*try to open dsp. If failed, kill sound daemons if allowed by user, and try agin. If fail again, display the error message. Close it in success*/
 int try_open_dsp(LinphoneCore *lc)
@@ -311,19 +199,6 @@ int try_open_dsp(LinphoneCore *lc)
 	return retval;
 }
 
-void check_for_registration(LinphoneCore *lc)
-{
-	registrar_config_t *reg_conf;
-	reg_conf=&lc->sip_conf.reg_conf;
-	if (reg_conf->use_registrar){
-		if (reg_conf->expires>0){
-			gdouble time;
-			time=g_timer_elapsed(reg_conf->timer,NULL);
-			if ( ((int)time) > reg_conf->expires) do_registration(lc,1);
-		}
-	}
-}
-
 char *int2str(int number)
 {
 	gchar *numstr=g_malloc(10);
@@ -360,7 +235,9 @@ void check_sound_device(LinphoneCore *lc)
 		file[a]='\0';
 		i810_audio=strstr(file,"i810_audio");
 		if (i810_audio!=NULL){
-			lc->vtable.display_warning(lc,_("You are currently using the i810_audio driver.\nThis driver is buggy and so does not work with Linphone.\nWe suggest that you replace it by its equivalent ALSA driver,\neither with packages from your distribution, or by downloading\nALSA drivers at http://www.alsa-project.org."));
+			/* I'm sorry i put this warning in comments because
+			 * i don't use yet the right driver !! */
+/*			lc->vtable.display_warning(lc,_("You are currently using the i810_audio driver.\nThis driver is buggy and so does not work with Linphone.\nWe suggest that you replace it by its equivalent ALSA driver,\neither with packages from your distribution, or by downloading\nALSA drivers at http://www.alsa-project.org."));*/
 			goto end;
 		}
 		snd_pcm=strstr(file,"snd-pcm");
@@ -439,10 +316,10 @@ gint payload_type_get_rate(PayloadType *pt){
 
 
 
-/* return 0 if codec can be used with bandwidth, -1 else*/
-int payload_type_check_usable(PayloadType *pt,double bandwidth)
+/* return TRUE if codec can be used with bandwidth, FALSE else*/
+gboolean payload_type_check_usable(PayloadType *pt,double bandwidth)
 {
-	int ret=0;
+	gboolean ret=0;
 	double codec_band;
 	double npacket;
 	double packet_size;
@@ -458,9 +335,11 @@ int payload_type_check_usable(PayloadType *pt,double bandwidth)
 			//g_message("Payload %s: %g",pt->mime_type,codec_band);
 			break;
 		case PAYLOAD_VIDEO:
-			ret=-1;
+			if (bandwidth>=128000) ret=TRUE;
+			else ret=FALSE;
+			break;
 	}
-	
+	/*if (!ret) g_warning("Payload %s is not usable with your internet connection.",pt->mime_type);*/
 	
 	return ret;
 }
@@ -470,8 +349,7 @@ void linphone_core_check_codecs_for_bandwidth(LinphoneCore *lc)
 	GList *elem;
 	PayloadType *pt;
 	
-	elem=lc->codecs_conf.audio_codecs;
-	while(elem!=NULL)
+	for(elem=lc->codecs_conf.audio_codecs;elem!=NULL;elem=g_list_next(elem))
 	{
 		pt=(PayloadType*)elem->data;
 		if (strcmp("speex",pt->mime_type)==0 && pt->clock_rate==8000){
@@ -479,9 +357,12 @@ void linphone_core_check_codecs_for_bandwidth(LinphoneCore *lc)
 				pt->normal_bitrate=8000;
 			}else pt->normal_bitrate=20000;
 		}	
-		payload_type_set_usable(pt,payload_type_check_usable(pt,lc->net_conf.bandwidth));
-		
-		elem=g_list_next(elem);
+		payload_type_set_usable(pt,payload_type_check_usable(pt,lc->net_conf.bandwidth));	
+	}
+	for(elem=lc->codecs_conf.video_codecs;elem!=NULL;elem=g_list_next(elem))
+	{
+		pt=(PayloadType*)elem->data;
+		payload_type_set_usable(pt,payload_type_check_usable(pt,lc->net_conf.bandwidth));	
 	}
 }
 
@@ -569,7 +450,7 @@ void linphone_core_setup_local_rtp_profile(LinphoneCore *lc)
 					if (codec!=NULL){
 						payload_type_set_enable(payload,1);
 						payload_type_set_user_data(payload,(gpointer)codec);
-						audiopt=g_list_append(videopt,(gpointer)payload);
+						videopt=g_list_append(videopt,(gpointer)payload);
 					}
 					break;
 				default:
@@ -587,28 +468,64 @@ void linphone_core_setup_local_rtp_profile(LinphoneCore *lc)
 	linphone_core_check_codecs_for_bandwidth(lc);
 }
 
-int from_2char_without_params(from_t *from,char **str)
+int from_2char_without_params(osip_from_t *from,char **str)
 {
-	gchar *tmp=NULL;
-	*str=NULL;
-	if (from->displayname!=NULL){
-		if (from->url->username!=NULL){
-			tmp=g_strdup_printf("%s <sip:%s@%s>",from->displayname,from->url->username,
-								from->url->host);
-		}else{
-			tmp=g_strdup_printf("%s <sip:%s>",from->displayname,
-								from->url->host);
-		}
-	}else{
-		if (from->url->username!=NULL){
-			tmp=g_strdup_printf("sip:%s@%s",from->url->username,from->url->host);
-		}else{
-			tmp=g_strdup_printf("sip:%s",from->url->host);
-		}
-		
+	osip_from_t *tmpfrom;
+	int i;
+	osip_from_clone(from,&tmpfrom);
+	while(!osip_list_eol(tmpfrom->gen_params,0)){
+		osip_generic_param_t *param=(osip_generic_param_t*)osip_list_get(tmpfrom->gen_params,0);
+		osip_generic_param_free(param);
+		osip_list_remove(tmpfrom->gen_params,0);
 	}
-	g_return_val_if_fail(tmp!=NULL,-1);
-	*str=sgetcopy(tmp);
-	g_free(tmp);
+	osip_from_to_str(tmpfrom,str);
+	osip_from_free(tmpfrom);
 	return 0;
 }
+
+#if defined(HAVE_GETIFADDRS) && defined(INET6)
+#include <sys/types.h>
+#include <sys/socket.h>
+#include <ifaddrs.h>
+gboolean host_has_ipv6_network()
+{
+	struct ifaddrs *ifp;
+	struct ifaddrs *ifpstart;
+	gboolean ipv6_present=FALSE;
+	
+	if (getifaddrs (&ifpstart) < 0)
+	{
+		return FALSE;
+	}
+	
+	for (ifp=ifpstart; ifp != NULL; ifp = ifp->ifa_next)
+	{
+		interface_t *netif;
+		if (!ifp->ifa_addr)
+		  continue;
+
+		switch (ifp->ifa_addr->sa_family) {
+		case AF_INET:
+		        
+			break;
+		case AF_INET6:
+		    ipv6_present=TRUE;
+			break;
+		default:
+		        continue;
+  		}
+	}
+
+	freeifaddrs (ifpstart);
+
+	return ipv6_present;
+}
+#else
+
+gboolean host_has_ipv6_network()
+{
+	return FALSE;
+}
+
+
+#endif
