@@ -19,24 +19,18 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 #ifndef OSIPUACB_H
 #define OSIPUACB_H
-#include <osipua.h>
-#include "../osipua/src/sdphandler.h"
-
-int invite_accepted_cb(OsipDialog *, transaction_t *, sip_t *, void *);
-int bye_cb(OsipDialog *, transaction_t *, sip_t *, void *);
-int faillure_cb(OsipDialog *, transaction_t *, sip_t *, void *);
-int invite_cb(OsipDialog *, transaction_t *, sip_t *, void *);
-int informative_cb(OsipDialog *, transaction_t *, sip_t *, void *);
+#include <eXosip.h>
+#include "sdphandler.h"
 
 
 /* these are the SdpHandler callbacks: we are called in to be aware of the content
 of the SDP messages exchanged */
 
-int set_audio_offer(SdpHandler *sdph,SdpContext *ctx);
-int set_video_offer(SdpHandler *sdph,SdpContext *ctx);
-int accept_audio_offer(SdpHandler *sdph,SdpContext *ctx,SdpPayload *payload);
-int accept_video_offer(SdpHandler *sdph,SdpContext *ctx,SdpPayload *payload);
-int read_audio_answer(SdpHandler *sdph,SdpContext *ctx,SdpPayload *payload);
-int read_video_answer(SdpHandler *sdph,SdpContext *ctx,SdpPayload *payload);
+int linphone_set_audio_offer(sdp_context_t *ctx);
+int linphone_set_video_offer(sdp_context_t *ctx);
+int linphone_accept_audio_offer(sdp_context_t *ctx,sdp_payload_t *payload);
+int linphone_accept_video_offer(sdp_context_t *ctx,sdp_payload_t *payload);
+int linphone_read_audio_answer(sdp_context_t *ctx,sdp_payload_t *payload);
+int linphone_read_video_answer(sdp_context_t *ctx,sdp_payload_t *payload);
 
 #endif
