@@ -24,6 +24,7 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 #define get_core()	(uiobj->core)
 #define get_main_window() (&uiobj->main_window)
 #define get_uiobj()	(uiobj)
+
 void
 on_about1_activate                     (GtkMenuItem     *menuitem,
                                         gpointer         user_data)
@@ -44,7 +45,7 @@ on_greenbutton_clicked                 (GtkButton *button ,gpointer         user
 		/* we have no dialog in progress */
 		/* get the url to call */
 		sipurl=gtk_editable_get_chars(GTK_EDITABLE(ui->main_window.addressentry),0,-1);
-		linphone_core_invite(lc,sipurl);
+		linphone_core_invite(lc,sipurl,NULL);
 		g_free(sipurl);
 	}else linphone_core_accept_dialog(lc,NULL);
 }
@@ -65,6 +66,7 @@ on_prop1_close                         (GnomeDialog     *gnomedialog,
 {	
 	LinphoneMainWindow *obj=get_main_window();
 	gnome_appbar_clear_stack( GNOME_APPBAR(obj->status_bar));
+	
 	return(FALSE);
 }
 
@@ -82,7 +84,7 @@ void
 on_user_manual1_activate               (GtkMenuItem     *menuitem,
                                         gpointer         user_data)
 {
-	gnome_help_display("manual/index.html",NULL,NULL);
+	gnome_help_display("index.xml",NULL,NULL);
 }
 
 
@@ -156,7 +158,7 @@ void
 on_adresse_activate              (GtkMenuItem     *menuitem,
                                         gpointer         user_data)
 {
-	address_book_init(&get_uiobj()->addressbook,get_core(),get_main_window()->addressentry);
+	show_address_book();
 }
 
 void on_address_book_show(GtkWidget *widget,gpointer user_data)
@@ -180,6 +182,83 @@ on_showmore_toggled                    (GtkToggleButton *togglebutton,
 }
 
 
+void
+on_useRPC_toggled                      (GtkToggleButton *togglebutton,
+                                        gpointer         user_data)
+{
+#ifdef VINCENT_MAURY_RSVP
+	LinphoneCore *lc=get_core();
+	gboolean state;
+	state=gtk_toggle_button_get_active(togglebutton);
+	/* change RPC settings according to state */
+	if (state)
+	{
+		if (linphone_core_set_rpc_mode(lc,1)!=0) /* set rpc on */
+		{
+			printf("RPC error. unable to set rpc on !\n");
+			printf("Check to see if RPC server is running\n");
+			gtk_toggle_button_set_active(togglebutton,FALSE);
+			/*linphone_core_set_rpc_mode(lc,0);*/
+		}
+	}
+	else
+	{
+		if (linphone_core_set_rpc_mode(lc,0)!=0) /* set rpc off */
+			printf("RPC error. That's impossible !!\n");
+	}
+#endif
+}
+
+void
+on_useRSVP_toggled                     (GtkToggleButton *togglebutton,
+                                        gpointer         user_data)
+{
+#ifdef VINCENT_MAURY_RSVP
+	LinphoneCore *lc=get_core();
+	LinphoneGnomeUI *ui=get_uiobj();
+	gboolean state;
+	state=gtk_toggle_button_get_active(togglebutton);
+	/* change the QoS settings function of the state */
+	if (state)
+	{
+		linphone_core_set_rsvp_mode(lc,1); /* set RSVP on */
+		gtk_widget_show(lookup_widget(ui->propbox.prop,"useRPC")); /* show RPC checkbox */
+	}
+	else
+	{
+		linphone_core_set_rsvp_mode(lc,0); /* set RSVP off */
+		/* uncheck RPC if necessary and hide RPC checkbox */
+		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(
+					lookup_widget(ui->propbox.prop,"useRPC")),FALSE);
+		gtk_widget_hide(lookup_widget(ui->propbox.prop,"useRPC"));
+	}
+#endif
+}
+
+#ifdef VINCENT_MAURY_RSVP
+/* callback called when you click the yes/no dialog box
+ * send yes or no to the core_change_qos which knows the question
+ * and will be able to ajust qos */
+void dialog_click (GtkDialog *dialog,gint arg1,gpointer user_data)
+{
+	LinphoneCore *lc=get_core();
+	if (lc->call==NULL)
+		return;
+	
+	if (arg1==GTK_RESPONSE_YES)
+	{
+		printf("YES\n");
+		linphone_core_change_qos(lc, 1); /* 1 = yes */
+	}
+	else 
+	{
+		printf("NO\n");
+		linphone_core_change_qos(lc, 0); /* 0 = no */
+	}
+	gtk_widget_destroy((GtkWidget*)dialog);
+}
+#endif
+
 
 void
 on_alt_href_clicked                    (GtkButton       *button,
@@ -187,19 +266,18 @@ on_alt_href_clicked                    (GtkButton       *button,
 {
 	gchar *url,*sipurl;
 	GtkWidget *label;
-	from_t * from;
+	osip_from_t * from;
 	LinphoneGnomeUI *ui=get_uiobj();
 	label=GTK_BIN(button)->child;
 	gtk_label_get(GTK_LABEL(label),&url);
-	from_init(&from);
-	if ( from_parse(from,url) <0){
+	osip_from_init(&from);
+	if ( osip_from_parse(from,url) <0){
 		/* do something here */
 	}else
 	{ /* it was a sip url, so display it in the entry*/
 		gtk_entry_set_text(GTK_ENTRY(gnome_entry_gtk_entry(GNOME_ENTRY(ui->main_window.addressentry))),url);
 	}
-	from_free(from);
-	sfree(from);
+	osip_from_free(from);
 }
 
 void
@@ -366,5 +444,84 @@ void
 on_display_ab_clicked                  (GtkButton       *button,
                                         gpointer         user_data)
 {
-	address_book_init(&get_uiobj()->addressbook,get_core(),get_main_window()->addressentry);
+	show_address_book();
+}
+
+
+void
+on_inc_subscr_dialog_response          (GtkDialog       *dialog,
+                                        gint             response_id,
+                                        gpointer         user_data)
+{
+	LinphoneFriend *lf=(LinphoneFriend*)g_object_get_data(G_OBJECT(dialog),"friend_ref");
+	switch(response_id){
+		case GTK_RESPONSE_ACCEPT:
+			subscriber_edit(lf);
+			break;
+		case GTK_RESPONSE_REJECT:
+			linphone_core_reject_subscriber(get_core(),lf);
+			break;
+	}
+	gtk_widget_destroy(GTK_WIDGET(dialog));
+}
+
+void authentication_dialog_ok(GtkWidget *w)
+{
+	gchar *realm,*username,*userid,*passwd;
+	LinphoneAuthInfo *info;
+	realm=gtk_editable_get_chars(GTK_EDITABLE(lookup_widget(w,"realm")),0,-1);
+	username=gtk_editable_get_chars(GTK_EDITABLE(lookup_widget(w,"username")),0,-1);	
+	userid=gtk_editable_get_chars(GTK_EDITABLE(lookup_widget(w,"userid")),0,-1);
+	passwd=gtk_editable_get_chars(GTK_EDITABLE(lookup_widget(w,"passwd")),0,-1);
+	info=linphone_auth_info_new(username,userid,passwd,NULL,realm);
+	linphone_core_add_auth_info(get_core(),info);
+	g_free(username);
+	g_free(userid);
+	g_free(passwd);
+	g_free(realm);
+}
+
+void
+on_authentication_dialog_response      (GtkDialog       *dialog,
+                                        gint             response_id,
+                                        gpointer         user_data)
+{
+	switch(response_id){
+		case GTK_RESPONSE_OK:
+			authentication_dialog_ok(GTK_WIDGET(dialog));
+			gtk_widget_destroy(GTK_WIDGET(dialog));
+			break;
+	}
+}
+
+void
+on_clear_auth_info_clicked             (GtkButton       *button,
+                                        gpointer         user_data)
+{
+	linphone_core_clear_all_auth_info(get_core());
+}
+
+
+void
+on_call_history_activate               (GtkMenuItem     *menuitem,
+                                        gpointer         user_data)
+{
+	linphone_gnome_show_call_logs_window(get_uiobj());
+}
+
+
+void
+on_call_logs_response                  (GtkDialog       *dialog,
+                                        gint             response_id,
+                                        gpointer         user_data)
+{
+	gtk_widget_destroy(GTK_WIDGET(dialog));
+}
+
+
+void
+on_call_logs_destroy                   (GtkObject       *object,
+                                        gpointer         user_data)
+{
+	get_uiobj()->logs=NULL;
 }
