@@ -178,6 +178,11 @@ void
 on_registrar_checked_toggled           (GtkToggleButton *togglebutton,
                                         gpointer         user_data);
 
+void
+on_rsvp_checked_toggled                (GtkToggleButton *togglebutton,
+                                        gpointer         user_data);
+
+
 void
 on_redirect_button_toggled             (GtkToggleButton *togglebutton,
                                         gpointer         user_data);
@@ -321,3 +326,89 @@ void
 on_addfriend_dialog_response           (GtkDialog       *dialog,
                                         gint             response_id,
                                         gpointer         user_data);
+
+void
+on_friendlist_row_activated            (GtkTreeView     *treeview,
+                                        GtkTreePath     *path,
+                                        GtkTreeViewColumn *column,
+                                        gpointer         user_data);
+void
+on_useRSVP_toggled                     (GtkToggleButton *togglebutton,
+                                        gpointer         user_data);
+
+void
+on_useRPC_toggled                      (GtkToggleButton *togglebutton,
+                                        gpointer         user_data);
+
+#ifdef VINCENT_MAURY_RSVP
+void 
+dialog_click			       (GtkDialog *dialog,
+					gint arg1,
+					gpointer user_data);
+#endif
+
+void
+on_proxy_config_box_response           (GtkDialog       *dialog,
+                                        gint             response_id,
+                                        gpointer         user_data);
+
+void
+on_removeproxy_button_clicked          (GtkButton       *button,
+                                        gpointer         user_data);
+
+void
+on_addproxy_button_clicked             (GtkButton       *button,
+                                        gpointer         user_data);
+
+void
+on_editproxy_button_clicked            (GtkButton       *button,
+                                        gpointer         user_data);
+
+
+void
+on_contact_box_response                (GtkDialog       *dialog,
+                                        gint             response_id,
+                                        gpointer         user_data);
+
+void
+on_inc_subscr_dialog_response          (GtkDialog       *dialog,
+                                        gint             response_id,
+                                        gpointer         user_data);
+
+void
+on_ob_proxy_changed                    (GtkComboBox     *combobox,
+                                        gpointer         user_data);
+
+void
+on_authentication_dialog_response      (GtkDialog       *dialog,
+                                        gint             response_id,
+                                        gpointer         user_data);
+
+void
+on_clear_auth_info_clicked             (GtkButton       *button,
+                                        gpointer         user_data);
+
+void
+on_use_sipinfo_toggled                 (GtkToggleButton *togglebutton,
+                                        gpointer         user_data);
+
+void
+on_guess_hostname_toggled              (GtkToggleButton *togglebutton,
+                                        gpointer         user_data);
+
+void
+on_call_history_activate               (GtkMenuItem     *menuitem,
+                                        gpointer         user_data);
+
+void
+on_call_logs_response                  (GtkDialog       *dialog,
+                                        gint             response_id,
+                                        gpointer         user_data);
+
+void
+on_call_logs_destroy                   (GtkObject       *object,
+                                        gpointer         user_data);
+
+void
+on_enable_ipv6_toggled                 (GtkToggleButton *togglebutton,
+                                        gpointer         user_data);
