@@ -25,13 +25,15 @@ typedef struct _LinphoneMainWindow
 	GtkWidget *dtmfentry;
 	PresenceBox presencebox;
 	FriendList friendlist;
+	gboolean shown_once;
 }LinphoneMainWindow;
 
 typedef struct _LinphoneGnomeUI
 {
 	LinphoneMainWindow main_window;
 	LinphonePropertyBox propbox;
-	AddressBook	addressbook;
+	GtkWidget *ab;	/*the address book */
+	GtkWidget *logs;	/* the call logs window */
 	LinphoneCore *core;
 	guint timeout_id;
 }LinphoneGnomeUI;
@@ -45,5 +47,10 @@ void linphone_gnome_uninit(LinphoneGnomeUI *ui);
 
 extern LinphoneGnomeUI *uiobj;
 
-
+GtkWidget *proxy_combo_box_new(LinphoneProxyConfig *selected);
+void linphone_refresh_proxy_combo_box(GtkWidget *window);
+LinphoneProxyConfig *proxy_combo_box_get_selected(GtkWidget *combo);
+void linphone_gnome_show_call_logs_window(LinphoneGnomeUI *ui);
+void linphone_gnome_update_call_logs(LinphoneGnomeUI *ui);
+void linphone_gnome_ui_display_something(LinphoneGnomeUI *ui,GtkMessageType type,const gchar *message);
 #endif
