@@ -42,10 +42,11 @@ void
 on_reachable                           (GtkToggleButton *togglebutton,gpointer         user_data)
 {
 	PresenceBox *p=get_presence_box();
-	gtk_widget_set_sensitive(p->contact_field,FALSE);
+	if (!gtk_toggle_button_get_active(togglebutton)) return;
+	//gtk_widget_set_sensitive(p->contact_field,FALSE);
 	p->toggled_button=PRESENCE_MODE_REACHABLE;
-	gtk_widget_set_sensitive(p->minutesaway,FALSE);
-	gtk_widget_set_sensitive(p->contact_field,FALSE);
+	//gtk_widget_set_sensitive(p->minutesaway,FALSE);
+	//gtk_widget_set_sensitive(p->contact_field,FALSE);
 	presence_box_changed(p);
 }
 
@@ -54,9 +55,10 @@ void
 on_busy                                (GtkToggleButton *togglebutton,gpointer         user_data)
 {
 	PresenceBox *p=get_presence_box();
-	gtk_widget_set_sensitive(p->contact_field,FALSE);
+	if (!gtk_toggle_button_get_active(togglebutton)) return;
+	//gtk_widget_set_sensitive(p->contact_field,FALSE);
 	p->toggled_button=PRESENCE_MODE_BUSY;
-	gtk_widget_set_sensitive(p->minutesaway,TRUE);
+	//gtk_widget_set_sensitive(p->minutesaway,TRUE);
 	presence_box_changed(p);
 }
 
@@ -73,8 +75,9 @@ void
 on_away                                (GtkToggleButton *togglebutton,gpointer         user_data)
 {
 	PresenceBox *p=get_presence_box();
-	gtk_widget_set_sensitive(p->contact_field,FALSE);
-	gtk_widget_set_sensitive(p->minutesaway,TRUE);
+	if (!gtk_toggle_button_get_active(togglebutton)) return;
+	//gtk_widget_set_sensitive(p->contact_field,FALSE);
+	//gtk_widget_set_sensitive(p->minutesaway,TRUE);
 	p->toggled_button=PRESENCE_MODE_AWAY;
 	presence_box_changed(p);
 }
@@ -84,8 +87,9 @@ void
 on_do_not_disturb                      (GtkToggleButton *togglebutton,gpointer         user_data)
 {
 	PresenceBox *p=get_presence_box();
-	gtk_widget_set_sensitive(p->contact_field,FALSE);
-	gtk_widget_set_sensitive(p->minutesaway,FALSE);
+	if (!gtk_toggle_button_get_active(togglebutton)) return;
+	//gtk_widget_set_sensitive(p->contact_field,FALSE);
+	//gtk_widget_set_sensitive(p->minutesaway,FALSE);
 	p->toggled_button=PRESENCE_MODE_NOT_DISTURB;
 	presence_box_changed(p);
 }
@@ -95,8 +99,9 @@ void
 on_moved_tmply                         (GtkToggleButton *togglebutton,gpointer         user_data)
 {
 	PresenceBox *p=get_presence_box();
-  gtk_widget_set_sensitive(p->contact_field,TRUE);
-  gtk_widget_set_sensitive(p->minutesaway,FALSE);
+	if (!gtk_toggle_button_get_active(togglebutton)) return;
+  //gtk_widget_set_sensitive(p->contact_field,TRUE);
+  //gtk_widget_set_sensitive(p->minutesaway,FALSE);
   p->toggled_button=PRESENCE_MODE_MOVED;
   presence_box_changed(p);
 }
@@ -106,8 +111,9 @@ void
 on_alt_serv                            (GtkToggleButton *togglebutton,gpointer         user_data)
 {
 	PresenceBox *p=get_presence_box();
-  gtk_widget_set_sensitive(p->contact_field,TRUE);
-  gtk_widget_set_sensitive(p->minutesaway,FALSE);
+	if (!gtk_toggle_button_get_active(togglebutton)) return;
+  //gtk_widget_set_sensitive(p->contact_field,TRUE);
+  //gtk_widget_set_sensitive(p->minutesaway,FALSE);
   p->toggled_button=PRESENCE_MODE_ALT_SERVICE;
   presence_box_changed(p);
 }
@@ -129,7 +135,7 @@ void presence_box_apply(PresenceBox *p)
 	tmp = gtk_editable_get_chars (GTK_EDITABLE(p->minutesaway),0,-1);
 	if (tmp!=NULL && strlen(tmp)>0)
 	{
-		minutes_away = satoi(tmp);
+		minutes_away = atoi(tmp);
 		g_free(tmp);
 	}
 	/* retrieve the alternate contact url */
