@@ -40,7 +40,7 @@ enum {
 #define get_core()			(uiobj->core)
 #define get_property_box()	(&uiobj->propbox)
 #define property_box_changed() 	gnome_property_box_changed(GNOME_PROPERTY_BOX ( (&uiobj->propbox)->prop))
-
+#define get_main_window() (&uiobj->main_window)
 
 
 void net_section_init(NetSection *sec, GtkWidget *prop)
@@ -53,6 +53,8 @@ void net_section_init(NetSection *sec, GtkWidget *prop)
 	sec->enable_nat=lookup_widget(prop,"enable_nat");
 	sec->nat_address=lookup_widget(prop,"nat_address");
 	sec->nat_label=lookup_widget(prop,"nat_label");
+	sec->use_sipinfo=lookup_widget(prop,"use_sipinfo");
+	sec->enable_ipv6=lookup_widget(prop,"enable_ipv6");
 }
 
 void codec_list_update(GtkTreeView *listview,double bandwidth);
@@ -173,7 +175,10 @@ void net_section_fill(NetSection *sec,LinphoneCore *lc)
 		gtk_entry_set_text(GTK_ENTRY(sec->nat_address),tmp);
 		g_free(tmp);
 	}
-	
+	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(sec->use_sipinfo),
+		linphone_core_get_use_info_for_dtmf(lc));
+	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(sec->enable_ipv6),
+		linphone_core_ipv6_enabled(lc));
 }
 
 void
@@ -199,6 +204,12 @@ on_nat_address_changed                 (GtkEditable     *editable,
 	property_box_changed();
 }
 
+void
+on_enable_ipv6_toggled                 (GtkToggleButton *togglebutton,
+                                        gpointer         user_data)
+{
+	property_box_changed();
+}
 
 
 void net_section_apply(NetSection *sec,LinphoneCore *lc)
@@ -240,49 +251,67 @@ void net_section_apply(NetSection *sec,LinphoneCore *lc)
 	adj=gtk_spin_button_get_adjustment(GTK_SPIN_BUTTON(sec->au_port));
   	linphone_core_set_audio_port(lc,(gint)adj->value);
 	}
+	linphone_core_enable_ipv6(lc,gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(sec->enable_ipv6)));
 }
 
+
+enum{
+	PROXY_CONFIG_SERVER,
+	PROXY_CONFIG_REF,
+	PROXY_CONFIG_NCOL
+};
+
 void sip_section_init(SipSection *sec,GtkWidget *prop)
 {
+	
+	GtkListStore *store;
+	GtkTreeIter iter;
+	GtkCellRenderer *renderer;
+	GtkTreeViewColumn *column;
+	GtkTreeSelection *select;
 	sec->port=lookup_widget(prop,"sip_port");
 	sec->username=lookup_widget(prop, "user_name");
 	sec->hostname=lookup_widget(prop,"domain_name");
-	sec->registrar_checked=lookup_widget(prop, "registrar_checked");
-	sec->server_label=lookup_widget(prop,"server_label");
-	sec->server=lookup_widget(prop,"registrar_addr");
-	sec->password=lookup_widget(prop,"reg_passwd");
-	sec->password_label=lookup_widget(prop,"regpasslabel");
-	sec->addr_of_rec_label=lookup_widget(prop,"addressrec_label");
-	sec->addr_of_rec=lookup_widget(prop,"address_of_record");
-	sec->registrar_toggle=lookup_widget(prop,"registrar_checked");
-	sec->obproxy_button=lookup_widget(prop, "obproxy_button");
+	sec->proxy_list=lookup_widget(prop,"proxy_list");
+	sec->guess_hostname=lookup_widget(prop,"guess_hostname");
+	/* create the proxy list */
+	store = gtk_list_store_new (PROXY_CONFIG_NCOL, G_TYPE_STRING, G_TYPE_POINTER);
+	
+	gtk_tree_view_set_model(GTK_TREE_VIEW(sec->proxy_list),GTK_TREE_MODEL(store));
+	g_object_unref(G_OBJECT(store));
+	renderer = gtk_cell_renderer_text_new ();
+	column = gtk_tree_view_column_new_with_attributes (_("Server address"),
+                                                   renderer,
+                                                   "text", PROXY_CONFIG_SERVER,
+                                                   NULL);
+	gtk_tree_view_append_column (GTK_TREE_VIEW (sec->proxy_list), column);
+	
+	select = gtk_tree_view_get_selection (GTK_TREE_VIEW (sec->proxy_list));
+	gtk_tree_selection_set_mode (select, GTK_SELECTION_SINGLE);
 }
 
-void sip_section_enable_registrar(SipSection *sec,LinphoneCore *lc, gboolean state)
-{
-	gtk_widget_set_sensitive(sec->server_label,state);
-	gtk_widget_set_sensitive(sec->server,state);
-	gtk_widget_set_sensitive(sec->password_label,state);
-	gtk_widget_set_sensitive(sec->password,state);
-	gtk_widget_set_sensitive(sec->addr_of_rec_label,state);
-	gtk_widget_set_sensitive(sec->addr_of_rec,state);
-	gtk_widget_set_sensitive(sec->obproxy_button,state);
-	
- 	if (state) {
-		gboolean flag;
-		linphone_core_get_registrar_usage(lc,NULL,&flag,NULL);
- 		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(sec->obproxy_button),flag);
- 	}
- 	else {
- 		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(sec->obproxy_button),0);
- 	}
+
+void proxy_list_fill(GtkTreeModel *model, LinphoneCore *lc){
+	GList *elem;
+	GtkTreeIter iter;
+	/* fill the proxy list */
+	gtk_list_store_clear(GTK_LIST_STORE(model));
+	elem=linphone_core_get_proxy_config_list(lc);
+	for(;elem!=NULL;elem=g_list_next(elem)){
+		LinphoneProxyConfig *pcfg=(LinphoneProxyConfig*)elem->data;
+		gtk_list_store_append(GTK_LIST_STORE(model),&iter);
+		gtk_list_store_set(GTK_LIST_STORE(model),&iter,PROXY_CONFIG_SERVER,pcfg->reg_proxy,
+			PROXY_CONFIG_REF,pcfg,-1);
+	}
 }
 
 void sip_section_fill(SipSection *sec, LinphoneCore *lc)
 {
-	from_t *contact;
+	osip_from_t *contact;
 	gchar *tmp;
 	gboolean  flag;
+	GtkTreeModel *model=gtk_tree_view_get_model(GTK_TREE_VIEW(sec->proxy_list));
+	
 	/* set sip port */
 	gtk_spin_button_set_value(GTK_SPIN_BUTTON(sec->port),
 				(gfloat)linphone_core_get_sip_port(lc));
@@ -292,23 +321,10 @@ void sip_section_fill(SipSection *sec, LinphoneCore *lc)
 	gtk_entry_set_text(GTK_ENTRY(sec->username),contact->url->username);
 	/* set domain name */
 	gtk_entry_set_text(GTK_ENTRY(sec->hostname),contact->url->host);
-	from_free(contact);
-	sfree(contact);
-	/* set registrar address*/
-	tmp=linphone_core_get_registrar_addr(lc);
-	if (tmp!=NULL) gtk_entry_set_text(GTK_ENTRY(sec->server),tmp);
-	/* set registrar password */
-	tmp=linphone_core_get_registrar_passwd(lc);
-	if (tmp!=NULL) gtk_entry_set_text(GTK_ENTRY(sec->password),tmp);
-	tmp=linphone_core_get_addr_of_rec(lc);
-	/* set address of record */
-	if (tmp==NULL) gtk_entry_set_text(GTK_ENTRY(sec->addr_of_rec),tmp);
-	linphone_core_get_registrar_usage(lc,&flag,NULL,NULL);
-	if (flag)
-	{
-		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(sec->registrar_toggle),1);
-		/* putting this button active will send the signal "toggled", and so the registrar_toggled is called to do all the work*/		
-	}
+	osip_from_free(contact);
+	proxy_list_fill(model,lc);
+	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(sec->guess_hostname),
+		linphone_core_get_guess_hostname(lc));
 }
 
 void sip_section_apply(SipSection *sec, LinphoneCore *lc)
@@ -335,25 +351,129 @@ void sip_section_apply(SipSection *sec, LinphoneCore *lc)
 		}
 		g_free(username);
 	}
-	
-	state=gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(sec->registrar_toggle));
-	if (state){
-		as_proxy=gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(sec->obproxy_button));
-		/* get the registrar url */
-		regaddr=gtk_editable_get_chars(GTK_EDITABLE(sec->server),0,-1);
-		/* get the address of record */
-		addr_of_rec=gtk_editable_get_chars(GTK_EDITABLE(sec->addr_of_rec),0,-1);
-		linphone_core_set_registrar_addr(lc,regaddr,addr_of_rec);
-		/* get the passwd */
-		passwd=gtk_editable_get_chars(GTK_EDITABLE(sec->password),0,-1);
-		linphone_core_set_registrar_passwd(lc,passwd);
-		g_free(regaddr);
-		g_free(addr_of_rec);
-		g_free(passwd);
-	}
-	linphone_core_set_registrar_usage(lc,state,as_proxy,0);
 }
 
+
+void
+on_addproxy_button_clicked           (GtkButton       *button,
+                                        gpointer         user_data)
+{
+	GtkWidget *w=create_proxy_config_box();
+	gtk_widget_show(w);
+	printf("add proxy pressed\n");
+}
+
+
+void
+on_editproxy_button_clicked          (GtkButton       *button,
+                                        gpointer         user_data)
+{
+	GtkWidget *w;
+	GtkTreeSelection *select;
+	GtkTreeIter iter;
+	GtkTreeModel *model;
+	LinphoneProxyConfig * cfg;
+	select = gtk_tree_view_get_selection (GTK_TREE_VIEW (get_property_box()->sip.proxy_list));
+	if (gtk_tree_selection_get_selected (select, &model, &iter))
+	{
+		gtk_tree_model_get (model, &iter,PROXY_CONFIG_REF , &cfg, -1);
+		gtk_list_store_remove(GTK_LIST_STORE(model), &iter);
+		linphone_proxy_config_edit(cfg);
+	}else return;
+	w=create_proxy_config_box();
+	gtk_widget_show(w);
+	if (cfg->reg_proxy!=NULL) gtk_entry_set_text(GTK_ENTRY(lookup_widget(w,"reg_proxy")),cfg->reg_proxy);
+	if (cfg->reg_route!=NULL) gtk_entry_set_text(GTK_ENTRY(lookup_widget(w,"reg_route")),cfg->reg_route);
+	if (cfg->reg_identity!=NULL) gtk_entry_set_text(GTK_ENTRY(lookup_widget(w,"reg_identity")),cfg->reg_identity);
+	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(lookup_widget(w,"reg_sendregister")),cfg->reg_sendregister);
+	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(lookup_widget(w,"publish")),cfg->publish);
+	gtk_spin_button_set_value(GTK_SPIN_BUTTON(lookup_widget(w,"reg_expires")),cfg->expires);
+	g_object_set_data(G_OBJECT(w),"edited_config",(gpointer)cfg);
+}
+
+
+void
+on_removeproxy_button_clicked          (GtkButton       *button,
+                                        gpointer         user_data)
+{
+	GtkTreeSelection *select;
+	GtkTreeIter iter;
+	GtkTreeModel *model;
+	LinphoneProxyConfig * cfg;
+	select = gtk_tree_view_get_selection (GTK_TREE_VIEW (get_property_box()->sip.proxy_list));
+	if (gtk_tree_selection_get_selected (select, &model, &iter))
+	{
+		gtk_tree_model_get (model, &iter,PROXY_CONFIG_REF , &cfg, -1);
+		gtk_list_store_remove(GTK_LIST_STORE(model), &iter);
+		linphone_core_remove_proxy_config(get_core(),cfg);
+		linphone_refresh_proxy_combo_box(get_main_window()->window);
+	}
+}
+
+void get_proxy_config_box_data(GtkWidget *dialog)
+{
+	gchar *tmp;
+	gboolean editing=FALSE;
+	LinphoneProxyConfig *cfg;
+	tmp=gtk_editable_get_chars(GTK_EDITABLE(lookup_widget(dialog,"reg_proxy")),0,-1);
+	cfg=(LinphoneProxyConfig*)g_object_get_data(G_OBJECT(dialog),"edited_config");
+	if (cfg==NULL){
+		cfg=linphone_proxy_config_new(tmp);
+		g_free(tmp);
+		if (cfg==NULL) {
+			/* set an error message here */
+			return;
+		}
+	}else{
+		linphone_proxy_config_set_server_addr(cfg,tmp);
+		g_free(tmp);
+		editing=TRUE;
+	}
+	tmp=gtk_editable_get_chars(GTK_EDITABLE(lookup_widget(dialog,"reg_route")),0,-1);
+	linphone_proxy_config_set_route(cfg,tmp);
+	g_free(tmp);
+	tmp=gtk_editable_get_chars(GTK_EDITABLE(lookup_widget(dialog,"reg_identity")),0,-1);
+	linphone_proxy_config_set_identity(cfg,tmp);
+	g_free(tmp);
+	tmp=gtk_editable_get_chars(GTK_EDITABLE(lookup_widget(dialog,"reg_expires")),0,-1);
+	{
+	  int exp;
+	  if (tmp!=NULL)
+	    {
+	      exp = atoi(tmp);
+	      if (exp<=0)
+		exp = 200; /* minimum */
+	      if (exp>7200)
+		exp = 7200; /* maximum */
+	      linphone_proxy_config_expires(cfg,exp);
+	    }
+	}
+	g_free(tmp);
+	linphone_proxy_config_enableregister(cfg,gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(lookup_widget(dialog,"reg_sendregister"))));
+	linphone_proxy_config_enable_publish(cfg,gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(lookup_widget(dialog,"publish"))));
+	if (editing) linphone_proxy_config_done(cfg);
+	else linphone_core_add_proxy_config(get_core(),cfg);
+	/* set the last entered/changed proxy as the default one */
+	linphone_core_set_default_proxy(get_core(),cfg);
+	proxy_list_fill(gtk_tree_view_get_model(GTK_TREE_VIEW(get_property_box()->sip.proxy_list)),get_core());
+	linphone_refresh_proxy_combo_box(get_main_window()->window);
+}
+
+void
+on_proxy_config_box_response           (GtkDialog       *dialog,
+                                        gint             response_id,
+                                        gpointer         user_data)
+{
+	switch(response_id){
+		case GTK_RESPONSE_OK:
+			get_proxy_config_box_data(GTK_WIDGET(dialog));
+			gtk_widget_destroy(GTK_WIDGET(dialog));
+			
+		break;
+	}
+}
+
+
 void codec_section_init(CodecSection *sec, GtkWidget *prop)
 {
 	sec->au_codec_list=lookup_widget(prop,"au_codec_list");
@@ -519,6 +639,18 @@ void sound_section_init(SoundSection *sec, GtkWidget *prop)
 	sec->ringfileentry=lookup_widget(prop,"ringfileentry");
 }
 
+void
+on_card_changed                        (GtkEditable     *editable,
+                                        gpointer         user_data)
+{
+	gchar *tmp;
+	
+	/* get sound device*/
+	tmp=gtk_editable_get_chars(editable,0,-1);
+	if (strlen(tmp)>0) linphone_core_set_sound_device_from_name(get_core(),tmp);
+	g_free(tmp);
+}
+
 void sound_section_fill(SoundSection *sec, LinphoneCore *lc)
 {
 	gchar *dsppath;
@@ -533,13 +665,13 @@ void sound_section_fill(SoundSection *sec, LinphoneCore *lc)
 	cardmanager=linphone_core_get_card_manager(lc);
 	
 	for (i=0;(card=snd_card_manager_get_card(cardmanager,i))!=0;i++){
-		cardlist=g_list_append(cardlist,snd_card_get_identifier(card));
+		cardlist=g_list_append(cardlist,(gpointer)snd_card_get_identifier(card));
 	}
 	gtk_combo_set_popdown_strings(GTK_COMBO(sec->card_combo),cardlist);
 	card=snd_card_manager_get_card(cardmanager,devid);
 	g_return_if_fail(card!=NULL);
 	gtk_entry_set_text (GTK_ENTRY (sec->card_entry),snd_card_get_identifier(card));
-	
+	g_signal_connect(G_OBJECT(sec->card_entry),"changed",(GCallback)on_card_changed,NULL);
 	/* select audio source*/
 	switch(linphone_core_get_sound_source(lc))
 	{
@@ -559,17 +691,7 @@ void sound_section_fill(SoundSection *sec, LinphoneCore *lc)
   }
 }
 
-void
-on_card_changed                        (GtkEditable     *editable,
-                                        gpointer         user_data)
-{
-	gchar *tmp;
-	
-	/* get sound device*/
-	tmp=gtk_editable_get_chars(editable,0,-1);
-	linphone_core_set_sound_device_from_name(get_core(),tmp);
-	g_free(tmp);
-}
+
 
 
 void sound_section_apply(SoundSection *sec, LinphoneCore *lc)
@@ -579,7 +701,7 @@ void sound_section_apply(SoundSection *sec, LinphoneCore *lc)
 	
 	/* get sound device*/
 	tmp=gtk_editable_get_chars(GTK_EDITABLE(sec->card_entry),0,-1);
-	linphone_core_set_sound_device_from_name(lc,tmp);
+	if (strlen(tmp)>0) linphone_core_set_sound_device_from_name(lc,tmp);
 	g_free(tmp);
 	
 	/* get audio source*/
@@ -607,14 +729,14 @@ void
 on_ringpreview_clicked                 (GtkButton       *button,
                                         gpointer         user_data)
 {
-  int err;
-  gchar *tmp;
-  LinphonePropertyBox *prop=get_property_box();
+	int err;
+	gchar *tmp;
+	LinphonePropertyBox *prop=get_property_box();
 	LinphoneCore *lc=get_core();
-  /* get ring path */
+	/* get ring path */
 	tmp=gtk_editable_get_chars(GTK_EDITABLE(gnome_file_entry_gtk_entry(GNOME_FILE_ENTRY(prop->sound.ringfileentry))),0,-1);
 	err=linphone_core_preview_ring(lc,tmp,ring_finished,(gpointer)button);
-  if (err==0) gtk_widget_set_sensitive(GTK_WIDGET(button),0);
+	if (err==0) gtk_widget_set_sensitive(GTK_WIDGET(button),0);
 	g_free(tmp);
 }
 
@@ -842,26 +964,10 @@ on_aucodec_disable_clicked             (GtkButton       *button,
 }
 
 
-
-void
-on_registrar_checked_toggled           (GtkToggleButton *togglebutton,
-                                        gpointer         user_data)
-{
-	gboolean state;
-	
-	state=gtk_toggle_button_get_active(togglebutton);
-	sip_section_enable_registrar(&(get_property_box()->sip),get_core(), state);	
-	property_box_changed();
-}
-
-
 void
 on_user_name_changed                   (GtkEditable     *editable,
                                         gpointer         user_data)
 {
-	GtkWidget *server=get_property_box()->sip.server;
-	gchar *tmp;
-	//on_registrar_addr_changed(GTK_EDITABLE(server),NULL);
 	property_box_changed();
 }
 
@@ -874,64 +980,6 @@ on_domain_name_changed                 (GtkEditable     *editable,
 }
 
 
-void
-on_registrar_addr_changed              (GtkEditable     *editable,
-                                        gpointer         user_data)
-{
-	GtkWidget *address_of_record=get_property_box()->sip.addr_of_rec;
-	GtkWidget *username=get_property_box()->sip.username;
-	url_t *url1,*url2;
-	gchar *hostname,*addrrec,*tmp;
-	gint err=0;
-	/* address of record domain host part should usually be also the name of the registrar when it is used*/
-	tmp=gtk_editable_get_chars(editable,0,-1);
-	if ((tmp!=NULL) && (strlen(tmp)!=0))
-	{
-		url_init(&url1);
-		err=url_parse(url1,tmp);
-		g_free(tmp);
-		if (err<0) {
-			url_free(url1);
-			sfree(url1);
-			return;
-		}
-	}
-	else return;
-	hostname=url1->host;
-	addrrec=gtk_editable_get_chars(GTK_EDITABLE(address_of_record),0,-1);
-	url_init(&url2);
-
-	if ((addrrec!=NULL) && (strlen(addrrec)!=0)){
-		err=url_parse(url2,addrrec);
-		//printf("address of record parsed with err=%i\n",err);
-		if (err<0) {url2->host=NULL;url2->username=NULL;};
-	}
-	if (url2->host!=NULL) sfree(url2->host);
-	if ((hostname!=NULL) && (strlen(hostname)!=0)) url2->host=sgetcopy(hostname);
-	else {
-		tmp=gtk_editable_get_chars(GTK_EDITABLE(get_property_box()->sip.hostname),0,-1);
-		url2->host=sgetcopy(tmp);
-		g_free(tmp);
-	}
-	//printf ("url2->host=%s\n",url2->host);
-	if (url2->username==NULL){
-		tmp=gtk_editable_get_chars(GTK_EDITABLE(username),0,-1);
-		url2->username=sgetcopy(tmp);
-		g_free(tmp);
-	}
-	url_setscheme(url2,sgetcopy("sip"));
-	url_2char(url2,&tmp) ;
-	if (tmp!=NULL){
-		//printf("New address of record is %s\n",tmp);
-		gtk_entry_set_text(GTK_ENTRY(address_of_record),tmp);
-		sfree(tmp);
-	}
-	url_free(url1);
-	sfree(url1);
-    url_free(url2);
-    sfree(url2);
-	property_box_changed();
-}
 
 void
 on_reg_passwd_changed                  (GtkEditable     *editable,
@@ -972,11 +1020,10 @@ on_ringfileentry_changed               (GtkEditable     *editable,
 
 void linphone_property_box_uninit(LinphonePropertyBox *box)
 {
-  memset(box,0, sizeof(LinphonePropertyBox));
+	memset(box,0, sizeof(LinphonePropertyBox));
 }
 
 
-
 gboolean
 on_property_box_closed                 (GnomeDialog     *gnomedialog,
                                         gpointer         user_data)
@@ -984,3 +1031,26 @@ on_property_box_closed                 (GnomeDialog     *gnomedialog,
   linphone_property_box_uninit(get_property_box());
   return FALSE;
 }
+
+void
+on_use_sipinfo_toggled                 (GtkToggleButton *togglebutton,
+                                        gpointer         user_data)
+{
+	linphone_core_set_use_info_for_dtmf(get_core(),gtk_toggle_button_get_active(togglebutton));
+}
+
+
+void
+on_guess_hostname_toggled              (GtkToggleButton *togglebutton,
+                                        gpointer         user_data)
+{
+	GtkWidget *hostname;
+	osip_from_t *from;
+	gboolean val=gtk_toggle_button_get_active(togglebutton);
+	linphone_core_set_guess_hostname(get_core(),val);
+	hostname=get_property_box()->sip.hostname;
+	from=linphone_core_get_primary_contact_parsed(get_core());
+	gtk_entry_set_text(GTK_ENTRY(hostname),from->url->host);
+	gtk_widget_set_sensitive(hostname,!val);
+	osip_from_free(from);
+}
