@@ -31,6 +31,8 @@ struct _NetSection
 	GtkWidget *enable_nat;
 	GtkWidget *nat_label;
 	GtkWidget *nat_address;
+	GtkWidget *use_sipinfo;
+	GtkWidget *enable_ipv6;
 };
 typedef struct _NetSection NetSection;
 
@@ -42,15 +44,8 @@ struct _SipSection
 	GtkWidget *port;
 	GtkWidget *username;
 	GtkWidget *hostname;
-	GtkWidget *registrar_checked;
-	GtkWidget *server_label;
-	GtkWidget *server;
-	GtkWidget *password_label;
-	GtkWidget *password;
-	GtkWidget *addr_of_rec_label;
-	GtkWidget *addr_of_rec;
-	GtkWidget *registrar_toggle;
-	GtkWidget *obproxy_button;
+	GtkWidget *proxy_list;
+	GtkWidget *guess_hostname;
 };
 
 typedef struct _SipSection SipSection;
@@ -102,4 +97,3 @@ typedef struct _LinphonePropertyBox LinphonePropertyBox;
 void linphone_property_box_init(LinphonePropertyBox *box);
 void linphone_property_box_apply(LinphonePropertyBox * box, LinphoneCore *lc, int page);
 void linphone_property_box_uninit(LinphonePropertyBox *box);
-
