@@ -22,6 +22,7 @@
 
 #ifdef HAVE_ALSA_ASOUNDLIB_H
 
+static gchar *over_pcmdev=NULL;
 
 #include "msossread.h"
 #include "msosswrite.h"
@@ -41,6 +42,7 @@ int alsa_set_params(AlsaCard *obj, int rw, int bits, int stereo, int rate)
 	gint periods=8;
 	gint periodsize=256;
 	gint err;
+	int format;
 	
 	if (rw) {
 		pcm_handle=obj->write_handle;
@@ -61,7 +63,12 @@ int alsa_set_params(AlsaCard *obj, int rw, int bits, int stereo, int rate)
       return(-1);
     }
 	/* Set sample format */
-    if (snd_pcm_hw_params_set_format(pcm_handle, hwparams, SND_PCM_FORMAT_S16_LE) < 0) {
+#ifdef WORDS_BIGENDIAN
+	format=SND_PCM_FORMAT_S16_BE;
+#else
+	format=SND_PCM_FORMAT_S16_LE;
+#endif
+    if (snd_pcm_hw_params_set_format(pcm_handle, hwparams, format) < 0) {
       g_warning("alsa_set_params: Error setting format.\n");
       return(-1);
     }
@@ -132,16 +139,16 @@ int alsa_set_params(AlsaCard *obj, int rw, int bits, int stereo, int rate)
     }
 	/*prepare sw params */
 	if (rw){
-	snd_pcm_sw_params_alloca(&swparams);
-	snd_pcm_sw_params_current(pcm_handle, swparams);
-	if ((err=snd_pcm_sw_params_set_start_threshold(pcm_handle, swparams,periodsize*2 ))<0){
-		g_warning("alsa_set_params: Error setting start threshold:%s",snd_strerror(err));
-		return -1;
-	}
-	if ((err=snd_pcm_sw_params(pcm_handle, swparams))<0){
-		g_warning("alsa_set_params: Error setting SW params:%s",snd_strerror(err));
-		return(-1);
-	}
+		snd_pcm_sw_params_alloca(&swparams);
+		snd_pcm_sw_params_current(pcm_handle, swparams);
+		if ((err=snd_pcm_sw_params_set_start_threshold(pcm_handle, swparams,periodsize*2 ))<0){
+			g_warning("alsa_set_params: Error setting start threshold:%s",snd_strerror(err));
+			return -1;
+		}
+		if ((err=snd_pcm_sw_params(pcm_handle, swparams))<0){
+			g_warning("alsa_set_params: Error setting SW params:%s",snd_strerror(err));
+			return(-1);
+		}
 	}
 	obj->frame_size=channels*(bits/8);
 	SND_CARD(obj)->bsize=periodsize*obj->frame_size;
@@ -156,8 +163,11 @@ int alsa_card_open_r(AlsaCard *obj,int bits,int stereo,int rate)
 	int bsize;
 	int err;
 	snd_pcm_t *pcm_handle;
+	gchar *pcmdev;
+	if (over_pcmdev!=NULL) pcmdev=over_pcmdev;
+	else pcmdev=obj->pcmdev;
 	
-	if (snd_pcm_open(&pcm_handle, obj->pcmdev,SND_PCM_STREAM_CAPTURE,SND_PCM_NONBLOCK) < 0) {
+	if (snd_pcm_open(&pcm_handle, pcmdev,SND_PCM_STREAM_CAPTURE,SND_PCM_NONBLOCK) < 0) {
 		g_warning("alsa_card_open_r: Error opening PCM device %s\n",obj->pcmdev );
 		return -1;
 	}
@@ -184,8 +194,11 @@ int alsa_card_open_w(AlsaCard *obj,int bits,int stereo,int rate)
 {
 	int err,bsize;
 	snd_pcm_t *pcm_handle;
+	gchar *pcmdev;
+	if (over_pcmdev!=NULL) pcmdev=over_pcmdev;
+	else pcmdev=obj->pcmdev;
 	
-	if (snd_pcm_open(&pcm_handle, obj->pcmdev,SND_PCM_STREAM_PLAYBACK,SND_PCM_NONBLOCK) < 0) {
+	if (snd_pcm_open(&pcm_handle, pcmdev,SND_PCM_STREAM_PLAYBACK,SND_PCM_NONBLOCK) < 0) {
       g_warning("alsa_card_open_w: Error opening PCM device %s\n", obj->pcmdev);
       return -1;
     }
@@ -277,7 +290,7 @@ int __alsa_card_read(AlsaCard *obj,char *buf,int bsize)
 		if (err<0) g_warning("alsa_card_read: snd_pcm_readi() failed:%s.",snd_strerror(err));
 	}
 	sigprocmask(SIG_UNBLOCK,&set,NULL);
-	return err;
+	return err*obj->frame_size;
 }
 
 int alsa_card_read(AlsaCard *obj,char *buf,int size)
@@ -383,6 +396,9 @@ static gint get_mixer_element(snd_mixer_t *mixer,const char *name, MixerAction a
 	const char *elemname;
 	snd_mixer_elem_t *elem;
 	int err;
+	long sndMixerPMin;
+	long sndMixerPMax;
+	long newvol;
 	elem=snd_mixer_first_elem(mixer);
 	while (elem!=NULL){
 		elemname=snd_mixer_selem_get_name(elem);
@@ -391,7 +407,10 @@ static gint get_mixer_element(snd_mixer_t *mixer,const char *name, MixerAction a
 			switch (action){
 				case CAPTURE:
 				if (snd_mixer_selem_has_capture_volume(elem)){
-					err=snd_mixer_selem_get_capture_volume(elem,SND_MIXER_SCHN_UNKNOWN,&value);
+					snd_mixer_selem_get_playback_volume_range(elem, &sndMixerPMin, &sndMixerPMax);
+					err=snd_mixer_selem_get_capture_volume(elem,SND_MIXER_SCHN_UNKNOWN,&newvol);
+					newvol-=sndMixerPMin;
+					value=(100*newvol)/(sndMixerPMax-sndMixerPMin);
 					if (err<0) g_warning("Could not get capture volume for %s:%s",name,snd_strerror(err));
 					//else g_message("Succesfully get capture level for %s.",elemname);
 					break;
@@ -399,7 +418,10 @@ static gint get_mixer_element(snd_mixer_t *mixer,const char *name, MixerAction a
 				break;
 				case PLAYBACK:
 				if (snd_mixer_selem_has_playback_volume(elem)){
-					err=snd_mixer_selem_get_playback_volume(elem,SND_MIXER_SCHN_FRONT_LEFT,&value);
+					snd_mixer_selem_get_playback_volume_range(elem, &sndMixerPMin, &sndMixerPMax);
+					err=snd_mixer_selem_get_playback_volume(elem,SND_MIXER_SCHN_FRONT_LEFT,&newvol);
+					newvol-=sndMixerPMin;
+					value=(100*newvol)/(sndMixerPMax-sndMixerPMin);
 					if (err<0) g_warning("Could not get playback volume for %s:%s",name,snd_strerror(err));
 					//else g_message("Succesfully get playback level for %s.",elemname);
 					break;
@@ -413,7 +435,7 @@ static gint get_mixer_element(snd_mixer_t *mixer,const char *name, MixerAction a
 		elem=snd_mixer_elem_next(elem);
 	}
 	
-	return (value*100)/30;
+	return value;
 }
 
 
@@ -421,6 +443,9 @@ static void set_mixer_element(snd_mixer_t *mixer,const char *name, gint level,Mi
 	const char *elemname;
 	snd_mixer_elem_t *elem;
 	int tmp;
+	long sndMixerPMin;
+	long sndMixerPMax;
+	long newvol;
 	
 	elem=snd_mixer_first_elem(mixer);
 	
@@ -431,14 +456,18 @@ static void set_mixer_element(snd_mixer_t *mixer,const char *name, gint level,Mi
 			switch(action){
 				case CAPTURE:
 				if (snd_mixer_selem_has_capture_volume(elem)){
-					snd_mixer_selem_set_capture_volume_all(elem,(level*30)/100);
+					snd_mixer_selem_get_playback_volume_range(elem, &sndMixerPMin, &sndMixerPMax);
+					newvol=(((sndMixerPMax-sndMixerPMin)*level)/100)+sndMixerPMin;
+					snd_mixer_selem_set_capture_volume_all(elem,newvol);
 					//g_message("Succesfully set capture level for %s.",elemname);
 					return;
 				}
 				break;
 				case PLAYBACK:
 				if (snd_mixer_selem_has_playback_volume(elem)){
-					snd_mixer_selem_set_playback_volume_all(elem,(level*30)/100);
+					snd_mixer_selem_get_playback_volume_range(elem, &sndMixerPMin, &sndMixerPMax);
+					newvol=(((sndMixerPMax-sndMixerPMin)*level)/100)+sndMixerPMin;
+					snd_mixer_selem_set_playback_volume_all(elem,newvol);
 					//g_message("Succesfully set playback level for %s.",elemname);
 					return;
 				}
@@ -557,12 +586,7 @@ SndCard * alsa_card_new(gint devid)
 	base= SND_CARD(obj);
 	snd_card_init(base);
 	
-#ifdef HAVE_GLIB
 	base->card_name=g_strdup_printf("%s (Advanced Linux Sound Architecture)",name);
-#else
-	base->card_name=malloc(100);
-	snprintf(base->card_name, 100, "%s (Advanced Linux Sound Architecture)",name);
-#endif
 	base->_probe=(SndCardOpenFunc)alsa_card_probe;
 	base->_open_r=(SndCardOpenFunc)alsa_card_open_r;
 	base->_open_w=(SndCardOpenFunc)alsa_card_open_w;
@@ -579,19 +603,9 @@ SndCard * alsa_card_new(gint devid)
 	base->_create_read_filter=(SndCardCreateFilterFunc)alsa_card_create_read_filter;
 	base->_create_write_filter=(SndCardCreateFilterFunc)alsa_card_create_write_filter;
 	
-#ifdef HAVE_GLIB
-	obj->pcmdev=g_strdup_printf("plughw:%i,0",devid);
-#else
-	obj->pcmdev=malloc(20);
-	sprintf(obj->pcmdev,"plughw:%i,0",devid);
-#endif
 	
-#ifdef HAVE_GLIB
+	obj->pcmdev=g_strdup_printf("plughw:%i,0",devid);
 	obj->mixdev=g_strdup_printf("hw:%i",devid);
-#else
-	obj->mixdev=malloc(40);
-	snprintf(obj->mixdev, 40, "hw:%i",devid);
-#endif
 	obj->readbuf=NULL;
 	obj->writebuf=NULL;
 	return base;
@@ -616,5 +630,11 @@ gint alsa_card_manager_init(SndCardManager *m, gint index)
 	return found;
 }
 
+void alsa_card_manager_set_default_pcm_device(gchar *pcmdev){
+	if (over_pcmdev!=NULL){
+		g_free(over_pcmdev);	
+	}
+	over_pcmdev=g_strdup(pcmdev);
+}
 
 #endif
