@@ -20,6 +20,12 @@
 
 
 #include "mediastream.h"
+#ifdef INET6
+	#include <sys/types.h>
+	#include <sys/socket.h>
+	#include <netdb.h>
+#endif
+
 
 #define MAX_RTP_SIZE	1500
 
@@ -75,29 +81,51 @@ static void on_timestamp_jump(RtpSession *s,guint32* ts, gpointer user_data)
 	rtp_session_reset(s);
 }
 
+static const char *ip4local="0.0.0.0";
+static const char *ip6local="::";
 
-void create_duplex_rtpsession(RtpProfile *profile, int locport,char *remip4,int remport,
+const char *get_local_addr_for(const char *remote)
+{
+	const char *ret;
+#ifdef INET6
+	char num[8];
+	struct addrinfo hints, *res0;
+	int err;
+	memset(&hints, 0, sizeof(hints));
+	hints.ai_family = PF_UNSPEC;
+	hints.ai_socktype = SOCK_DGRAM;
+	err = getaddrinfo(remote,"8000", &hints, &res0);
+	if (err!=0) {
+		g_warning ("get_local_addr_for: %s", gai_strerror(err));
+		return ip4local;
+	}
+	ret=(res0->ai_addr->sa_family==AF_INET6) ? ip6local : ip4local; 
+	freeaddrinfo(res0);
+#else
+	ret=ip4local;
+#endif
+	return ret;
+}
+
+void create_duplex_rtpsession(RtpProfile *profile, int locport,char *remip,int remport,
 				int payload,int jitt_comp,
 			RtpSession **recvsend){
 	RtpSession *rtpr;
 	rtpr=rtp_session_new(RTP_SESSION_SENDRECV);
 	rtp_session_max_buf_size_set(rtpr,MAX_RTP_SIZE);
 	rtp_session_set_profile(rtpr,profile);
-#ifdef INET6
-	rtp_session_set_local_addr(rtpr,"::",locport);
-#else
-	rtp_session_set_local_addr(rtpr,"0.0.0.0",locport);
-#endif
-	rtp_session_set_remote_addr(rtpr,remip4,remport);
+	rtp_session_set_local_addr(rtpr,get_local_addr_for(remip),locport);
+	if (remport>0) rtp_session_set_remote_addr(rtpr,remip,remport);
 	rtp_session_set_scheduling_mode(rtpr,0);
 	rtp_session_set_blocking_mode(rtpr,0);
 	rtp_session_set_payload_type(rtpr,payload);
 	rtp_session_set_jitter_compensation(rtpr,jitt_comp);
+	rtp_session_enable_adaptive_jitter_compensation(rtpr,TRUE);
 	rtp_session_signal_connect(rtpr,"timestamp_jump",(RtpCallback)on_timestamp_jump,NULL);
 	*recvsend=rtpr;
 }
 
-void create_rtp_sessions(RtpProfile *profile, int locport,char *remip4,int remport,
+void create_rtp_sessions(RtpProfile *profile, int locport,char *remip,int remport,
 				int payload,int jitt_comp,
 			RtpSession **recv, RtpSession **send){
 	RtpSession *rtps,*rtpr;
@@ -112,7 +140,7 @@ void create_rtp_sessions(RtpProfile *profile, int locport,char *remip4,int rempo
 #else
 	rtp_session_set_local_addr(rtps,"0.0.0.0",locport+2);
 #endif
-	rtp_session_set_remote_addr(rtps,remip4,remport);
+	rtp_session_set_remote_addr(rtps,remip,remport);
 	rtp_session_set_scheduling_mode(rtps,0);
 	rtp_session_set_blocking_mode(rtps,0);
 	rtp_session_set_payload_type(rtps,payload);
@@ -130,6 +158,7 @@ void create_rtp_sessions(RtpProfile *profile, int locport,char *remip4,int rempo
 	rtp_session_set_blocking_mode(rtpr,0);
 	rtp_session_set_payload_type(rtpr,payload);
 	rtp_session_set_jitter_compensation(rtpr,jitt_comp);
+	rtp_session_signal_connect(rtpr,"telephone-event",(RtpCallback)on_dtmf_received,NULL);
 	rtp_session_signal_connect(rtpr,"timestamp_jump",(RtpCallback)on_timestamp_jump,NULL);
 	*recv=rtpr;
 	*send=rtps;
@@ -137,16 +166,16 @@ void create_rtp_sessions(RtpProfile *profile, int locport,char *remip4,int rempo
 }
 
 
-AudioStream * audio_stream_start_full(RtpProfile *profile, int locport,char *remip4,int remport,
+AudioStream * audio_stream_start_full(RtpProfile *profile, int locport,char *remip,int remport,
 				int payload,int jitt_comp, gchar *infile, gchar *outfile, SndCard *sndcard)
 {
 	AudioStream *stream=g_new0(AudioStream,1);
 	RtpSession *rtps,*rtpr;
 	PayloadType *pt;
 	
-	//create_rtp_sessions(profile,locport,remip4,remport,payload,jitt_comp,&rtpr,&rtps);
+	//create_rtp_sessions(profile,locport,remip,remport,payload,jitt_comp,&rtpr,&rtps);
 	
-	create_duplex_rtpsession(profile,locport,remip4,remport,payload,jitt_comp,&rtpr);
+	create_duplex_rtpsession(profile,locport,remip,remport,payload,jitt_comp,&rtpr);
 	rtp_session_signal_connect(rtpr,"telephone-event",(RtpCallback)on_dtmf_received,(gpointer)stream);
 	rtps=rtpr;
 	
@@ -173,7 +202,7 @@ AudioStream * audio_stream_start_full(RtpProfile *profile, int locport,char *rem
 	if ((stream->encoder==NULL) || (stream->decoder==NULL)){
 		/* big problem: we have not a registered codec for this payload...*/
 		audio_stream_free(stream);
-		g_error("mediastream.c: No decoder availlable for payload %i.",payload);
+		g_error("mediastream.c: No decoder available for payload %i.",payload);
 		return NULL;
 	}
 	/* give the sound filters some properties */
@@ -203,23 +232,36 @@ AudioStream * audio_stream_start_full(RtpProfile *profile, int locport,char *rem
 	return stream;
 }
 
-AudioStream * audio_stream_start_with_files(RtpProfile *prof,int locport,char *remip4,
-		int remport,int profile,int jitt_comp,gchar *infile, gchar*outfile,SndCard *sndcard)
-{
-	return audio_stream_start_full(prof,locport,remip4,remport,profile,jitt_comp,infile,outfile,NULL);
+static int defcard=0;
+
+void audio_stream_set_default_card(int cardindex){
+	defcard=cardindex;
 }
 
-AudioStream * audio_stream_start(RtpProfile *prof,int locport,char *remip4,int remport,int profile,int jitt_comp)
+AudioStream * audio_stream_start_with_files(RtpProfile *prof,int locport,char *remip,
+		int remport,int profile,int jitt_comp,gchar *infile, gchar*outfile)
+{
+	return audio_stream_start_full(prof,locport,remip,remport,profile,jitt_comp,infile,outfile,NULL);
+}
+
+AudioStream * audio_stream_start(RtpProfile *prof,int locport,char *remip,int remport,int profile,int jitt_comp)
 {
 	SndCard *sndcard;
-	sndcard=snd_card_manager_get_card(snd_card_manager,0);
-	return audio_stream_start_full(prof,locport,remip4,remport,profile,jitt_comp,NULL,NULL,sndcard);
+	sndcard=snd_card_manager_get_card(snd_card_manager,defcard);
+	return audio_stream_start_full(prof,locport,remip,remport,profile,jitt_comp,NULL,NULL,sndcard);
 }
 
-AudioStream *audio_stream_start_with_sndcard(RtpProfile *prof,int locport,char *remip4,int remport,int profile,int jitt_comp,SndCard *sndcard)
+AudioStream *audio_stream_start_with_sndcard(RtpProfile *prof,int locport,char *remip,int remport,int profile,int jitt_comp,SndCard *sndcard)
 {
 	g_return_val_if_fail(sndcard!=NULL,NULL);
-	return audio_stream_start_full(prof,locport,remip4,remport,profile,jitt_comp,NULL,NULL,sndcard);
+	return audio_stream_start_full(prof,locport,remip,remport,profile,jitt_comp,NULL,NULL,sndcard);
+}
+
+void audio_stream_set_rtcp_information(AudioStream *st, const char *cname){
+	if (st->send_session!=NULL){
+		rtp_session_set_source_description(st->send_session,cname,NULL,NULL,NULL,NULL,"linphone-" LINPHONE_VERSION,
+											"This is free software (GPL) !");
+	}
 }
 
 void audio_stream_stop(AudioStream * stream)
