@@ -184,9 +184,9 @@ typedef struct _MSFilterInfo MSFilterInfo;
 
 void ms_filter_register(MSFilterInfo *finfo);
 void ms_filter_unregister(MSFilterInfo *finfo);
-MSFilterInfo * ms_filter_get_by_name(gchar *name);
+MSFilterInfo * ms_filter_get_by_name(const gchar *name);
 
-MSFilter * ms_filter_new_with_name(gchar *name);
+MSFilter * ms_filter_new_with_name(const gchar *name);
 
 
 
