@@ -19,7 +19,7 @@
 */
 
 #include "msrtpsend.h"
-#include <telephonyevents.h>
+#include <ortp/telephonyevents.h>
 #include "mssync.h"
 #include "mscodec.h"
 
