@@ -27,7 +27,7 @@
 
 #undef PACKAGE
 #undef VERSION
-#include <ortp.h>
+#include <ortp/ortp.h>
 
 
 /*this is the class that implements a sending through rtp filter*/
