@@ -27,12 +27,7 @@
 #ifdef HAVE_GLIB
 #include <glib.h>
 #else
-#undef VERSION
-#undef PACKAGE
-#include <rtpport.h>
-#undef VERSION
-#undef PACKAGE
-#include "glist.h"
+#include <uglib.h>
 #endif
 #include <errno.h>
 
