@@ -100,7 +100,7 @@ void snd_card_set_rec_source(SndCard *obj, int source); /* source='l' or 'm'*/
 void snd_card_set_level(SndCard *obj, int way, int level);
 gint snd_card_get_level(SndCard *obj,int way);
 
-gchar *snd_card_get_identifier(SndCard *obj);
+const gchar *snd_card_get_identifier(SndCard *obj);
 
 struct _MSFilter * snd_card_create_read_filter(SndCard *sndcard);
 struct _MSFilter * snd_card_create_write_filter(SndCard *sndcard);
@@ -116,7 +116,6 @@ int snd_card_destroy(SndCard *obj);
 #define SND_CARD(obj) ((SndCard*)(obj))
 
 
-typedef struct _OssCard HpuxSndCard;
 
 
 /* SndCardManager */
@@ -133,7 +132,7 @@ typedef struct _SndCardManager SndCardManager;
 
 void snd_card_manager_init(SndCardManager *manager);
 SndCard * snd_card_manager_get_card(SndCardManager *manager,int index);
-SndCard * snd_card_manager_get_card_with_string(SndCardManager *manager,char *cardname,int *index);
+SndCard * snd_card_manager_get_card_with_string(SndCardManager *manager,const char *cardname,int *index);
 
 extern SndCardManager *snd_card_manager;
 
