@@ -18,21 +18,13 @@
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
 
-#include "ms.h"
-#include "msfilter.h"
-#include "msv4l.h"
+#include "mediastream.h"
 
 
 int main()
 {
-	MSFilter *v4l;
-	
-	v4l=ms_v4l_new();
-	ms_video_source_set_device(MS_VIDEO_SOURCE(v4l),"/dev/video");
-	ms_v4l_start(MS_V4L(v4l));
-	v4l_read_process(MS_V4L(v4l));
-	v4l_read_process(MS_V4L(v4l));
-	v4l_read_process(MS_V4L(v4l));
-	ms_v4l_stop(MS_V4L(v4l));
+	ms_init();
+	video_preview_start("Video4Linux","/dev/video0");
+	sleep(5);
 	return 0;
 }
