@@ -17,8 +17,9 @@
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
 
-#include "ortp.h"
- 
+#include <ortp/ortp.h>
+#include "scheduler.h"
+#include <stdlib.h>
 
 rtp_stats_t ortp_global_stats;
 
@@ -26,11 +27,10 @@ rtp_stats_t ortp_global_stats;
 gint ortp_allocations=0;
 #endif
 
-#ifdef BUILD_SCHEDULER
-static RtpScheduler *ortp_scheduler;
-#endif
 
-#ifdef HAVE_GLIB
+RtpScheduler *__ortp_scheduler;
+
+
 void dummy_log(const gchar *log_domain,
                                              GLogLevelFlags log_level,
                                              const gchar *message,
@@ -38,10 +38,15 @@ void dummy_log(const gchar *log_domain,
 {
 	return;
 }
-#endif
 
 extern void av_profile_init(RtpProfile *profile);
 
+static void init_random_number_generator(){
+	struct timeval t;
+	gettimeofday(&t,NULL);
+	srandom(t.tv_usec+t.tv_sec);
+}
+
 /**
  *ortp_init:
  *
@@ -54,6 +59,7 @@ void ortp_init()
 	static gboolean initialized=FALSE;
 	if (initialized) return;
 	initialized=TRUE;
+
 #ifdef _WIN32
 	WORD wVersionRequested;
 	WSADATA wsaData;
@@ -62,16 +68,17 @@ void ortp_init()
 
 	if (WSAStartup(wVersionRequested,&wsaData)!=0) 
 	{
-		g_error("Impossible to initialise sockets");
+		g_error("Fail to initialise socket api");
 	}
 #endif
 
 #ifdef HAVE_GLIB
-	g_log_set_handler ("oRTP", G_LOG_LEVEL_MESSAGE, dummy_log, NULL);
 	if (!g_thread_supported()) g_thread_init (NULL);
 #endif
 	av_profile_init(&av_profile);
 	ortp_global_stats_reset();
+	init_random_number_generator();
+	g_message("oRTP-" ORTP_VERSION "initialized.");
 }
 
 
@@ -87,8 +94,7 @@ void ortp_scheduler_init()
 	static gboolean initialized=FALSE;
 	if (initialized) return;
 	initialized=TRUE;
-#ifdef BUILD_SCHEDULER
-#ifdef HOST_IS_HPUX
+#ifdef __hpux
 	/* on hpux, we must block sigalrm on the main process, because signal delivery
 	is ?random?, well, sometimes the SIGALRM goes to both the main thread and the 
 	scheduler thread */
@@ -96,14 +102,11 @@ void ortp_scheduler_init()
 	sigemptyset(&set);
 	sigaddset(&set,SIGALRM);
 	sigprocmask(SIG_BLOCK,&set,NULL);
-#endif /*HOST_IS_HPUX*/
+#endif /* __hpux */
 	if (!g_thread_supported()) g_thread_init(NULL);
-	ortp_scheduler=rtp_scheduler_new();
-	rtp_scheduler_start(ortp_scheduler);
+	__ortp_scheduler=rtp_scheduler_new();
+	rtp_scheduler_start(__ortp_scheduler);
 	//sleep(1);
-#else
-	g_warning("ortp_init_scheduler: ERROR: scheduler is not compiled !");
-#endif
 }
 
 
@@ -115,13 +118,11 @@ void ortp_scheduler_init()
 **/
 void ortp_exit()
 {
-#ifdef BUILD_SCHEDULER
-	if (ortp_scheduler!=NULL)
+	if (__ortp_scheduler!=NULL)
 	{
-		rtp_scheduler_destroy(ortp_scheduler);
-		ortp_scheduler=NULL;
+		rtp_scheduler_destroy(__ortp_scheduler);
+		__ortp_scheduler=NULL;
 	}
-#endif
 }
 
 /**
@@ -132,41 +133,62 @@ void ortp_exit()
  *
  *Returns: a pointer to the scheduler.
 **/
-#ifdef BUILD_SCHEDULER
 RtpScheduler * ortp_get_scheduler()
 {
-	if (ortp_scheduler==NULL) g_error("Cannot use the scheduled mode: the scheduler is not "
+	if (__ortp_scheduler==NULL) g_error("Cannot use the scheduled mode: the scheduler is not "
 									"started. Call ortp_scheduler_init() at the begginning of the application.");
-	return ortp_scheduler;
+	return __ortp_scheduler;
 }
-#endif
 
-#ifdef HAVE_GLIB
-void ortp_log( const gchar *log_domain,
-                                             GLogLevelFlags log_level,
-                                             const gchar *message,
-                                             gpointer user_data)
+
+void ortp_log(const gchar *log_domain,GLogLevelFlags log_level,
+                                           const gchar *message,
+                                           gpointer user_data)
 {
-	fprintf((FILE*) user_data,"%s: %s\n",log_domain,message);
+	gchar *lev;
+	switch(log_level){
+		case G_LOG_LEVEL_MESSAGE:
+			lev="message";
+			break;
+		case G_LOG_LEVEL_WARNING:
+			lev="warning";
+			break;
+		case G_LOG_LEVEL_ERROR:
+			lev="error";
+		default:
+			lev="(unknown log type)";
+	}
+	if (user_data==NULL){
+		user_data=stdout;
+	}
+	fprintf((FILE*)user_data,"%s-%s:%s\n",log_domain,lev,message);
 }
-#endif
 
-#ifndef TARGET_IS_HPUXKERNEL
+
 /**
  *ortp_set_debug_file:
  *@domain:	one of "oRTP" or "oRTP-stats" logging domain.
  *@file: a FILE pointer where to output the messages from the domain.
  *
+ * Warning: domain is ignored when not compiling with glib support.
 **/
 void ortp_set_debug_file(gchar *domain,FILE *file)
 {
-#ifdef HAVE_GLIB
 	if (file!=NULL)
-		g_log_set_handler (domain, G_LOG_LEVEL_MESSAGE, ortp_log, (gpointer)file);
-	else g_log_set_handler (domain, G_LOG_LEVEL_MESSAGE, dummy_log, NULL);
-#endif
+		g_log_set_handler (domain, G_LOG_LEVEL_MASK, ortp_log, (gpointer)file);
+	else g_log_set_handler (domain, G_LOG_LEVEL_MASK, dummy_log, NULL);
 }
-#endif
+/**
+ *ortp_set_log_handler:
+ *@domain: one of the "oRTP" or "oRTP-stats" logging domain.
+ *@func: your logging function, compatible with the GLogFunc prototype.
+ *
+ * Warning: domain is ignored when not compiling with glib support.
+**/
+void ortp_set_log_handler(const gchar *domain, GLogFunc func, gpointer userdata){
+	g_log_set_handler(domain,G_LOG_LEVEL_MASK,func,userdata);
+}
+
 
 
 void ortp_global_stats_display()
@@ -180,14 +202,28 @@ void ortp_global_stats_display()
 
 void rtp_stats_display(rtp_stats_t *stats, char *header)
 {
-#ifdef HAVE_GLIB
+
 	g_log("oRTP-stats",G_LOG_LEVEL_MESSAGE,
-#else
-	fprintf(stderr,
-#endif
-			"\n   %s :\n packet_sent=%lld\n sent=%lld bytes\n packet_recv=%lld\n hw_recv=%lld bytes\n recv=%lld bytes\n unavaillable=%lld bytes\n outoftime=%lld\n bad=%lld\n discarded=%lld\n",
-			header,stats->packet_sent,stats->sent,stats->packet_recv,stats->hw_recv, stats->recv,stats->unavaillable,
-			stats->outoftime,stats->bad,stats->discarded);
+			"\n   %s :\n"
+	      " packet_sent=%lld\n"
+	      " sent=%lld bytes\n"
+	      " packet_recv=%lld\n"
+	      " hw_recv=%lld bytes\n"
+	      " recv=%lld bytes\n"
+	      " unavaillable=%lld bytes\n"
+	      " outoftime=%lld\n"
+	      " bad=%lld\n"
+	      " discarded=%lld\n",
+	      header,
+	      (long long)stats->packet_sent,
+	      (long long)stats->sent,
+	      (long long)stats->packet_recv,
+	      (long long)stats->hw_recv,
+	      (long long)stats->recv,
+	      (long long)stats->unavaillable,
+	      (long long)stats->outoftime,
+	      (long long)stats->bad,
+	      (long long)stats->discarded);
 }
 
 void ortp_global_stats_reset(){
@@ -197,3 +233,24 @@ void ortp_global_stats_reset(){
 rtp_stats_t *ortp_get_global_stats(){
 	return &ortp_global_stats;
 }
+
+void rtp_stats_reset(rtp_stats_t *stats){
+	memset((void*)stats,0,sizeof(rtp_stats_t));
+}
+
+
+/**
+ *ortp_min_version_required:
+ *@major: 
+ *@minor: 
+ *@micro:
+ *
+ * This function give the opportunity to programs to check if the libortp they link to
+ * has the minimum version number they need.
+ *
+ * Returns: true if ortp has a version number greater or equal than the required one.
+**/
+gboolean ortp_min_version_required(int major, int minor, int micro){
+	return ((major*1000000) + (minor*1000) + micro) <= 
+		   ((ORTP_MAJOR_VERSION*1000000) + (ORTP_MINOR_VERSION*1000) + ORTP_MICRO_VERSION);
+}
