@@ -17,93 +17,58 @@
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
 
-#include "rtpport.h"
+#include <ortp/rtpport.h>
 #include "rtptimer.h"
 
-#ifdef BUILD_SCHEDULER
 
 #ifndef _WIN32
 
-#include <signal.h>
-#include <math.h>
+#ifdef __linux__
+#include <sys/select.h>
+#endif
+
+#include <sys/time.h>
+#include <sys/types.h>
+#include <unistd.h>
 
 
-static guint32 late_ticks;
-static struct timeval prev,new;
-static int alarm_received=0;	
-
+static struct timeval orig,cur;
 static guint32 posix_timer_time=0;		/*in milisecond */
 
 void posix_timer_init()
 {
-	struct itimerval timer;
-	sigset_t set;
-	/* block the SIGALRM signal */
-	sigemptyset(&set);
-	sigaddset(&set,SIGALRM);
-	sigprocmask(SIG_BLOCK,&set,NULL);
-	timer.it_value.tv_sec=posix_timer.interval.tv_sec;
-	timer.it_value.tv_usec=posix_timer.interval.tv_usec;
-	timer.it_interval.tv_sec=posix_timer.interval.tv_sec;
-	timer.it_interval.tv_usec=posix_timer.interval.tv_usec;
-	setitimer(ITIMER_REAL,&timer,NULL);
 	posix_timer.state=RTP_TIMER_RUNNING;
-	gettimeofday(&prev,NULL);
-	late_ticks=0;
+	gettimeofday(&orig,NULL);
 	posix_timer_time=0;
 }
 
 
 
-void dummy_handler(int signum)
-{
-	posix_timer_time+=POSIXTIMER_INTERVAL/1000;
-	alarm_received++;
-}
 
 void posix_timer_do()
 {
-	sigset_t set,oldset;
 	gint32 diff,time;
-	
-	if (late_ticks>0){
-		late_ticks--;
-		posix_timer_time+=POSIXTIMER_INTERVAL/1000;
-		return;
+	struct timeval tv;
+
+	gettimeofday(&cur,NULL);
+	time=((cur.tv_usec-orig.tv_usec)/1000 ) + ((cur.tv_sec-orig.tv_sec)*1000 );
+	if ( (diff=time-posix_timer_time)>50){
+		g_warning("Must catchup %i miliseconds.",diff);
 	}
-	
-	gettimeofday(&new,NULL);
-	time=((new.tv_usec-prev.tv_usec)/1000 ) + ((new.tv_sec-prev.tv_sec)*1000 );
-	diff=time-posix_timer_time;
-	if (diff> (POSIXTIMER_INTERVAL/1000)){
-		late_ticks=diff/(POSIXTIMER_INTERVAL/1000);
-		g_warning("we must catchup %i ticks.",late_ticks);
-		return;
-	}
-	
-	sigfillset(&set);
-	sigdelset(&set,SIGALRM);
-	alarm_received=0;
-	signal(SIGALRM,dummy_handler);
-	while (1) 
+	while((diff = posix_timer_time-time) > 0)
 	{
-		sigsuspend(&set);
-		if (alarm_received>1){
-			g_warning("alarm received=%i",alarm_received);
-		}
-		if (alarm_received==1) return;
-		g_warning("posix_timer_do: we received an unknow signal !!!!\n");
+		tv.tv_sec = diff/1000;
+		tv.tv_usec = (diff%1000)*1000;
+		select(0,NULL,NULL,NULL,&tv);
+		gettimeofday(&cur,NULL);
+		time=((cur.tv_usec-orig.tv_usec)/1000 ) + ((cur.tv_sec-orig.tv_sec)*1000 );
 	}
-	/* restore the old mask */
-	//sigprocmask(SIG_SETMASK,&oldset,NULL);
+	posix_timer_time+=POSIXTIMER_INTERVAL/1000;
+	
 }
 
 void posix_timer_uninit()
 {
-	struct itimerval timer;
-	/* unset the timer */
-	memset(&timer,0,sizeof(struct itimerval));
-	setitimer(ITIMER_REAL,&timer,NULL);
 	posix_timer.state=RTP_TIMER_STOPPED;
 }
 
@@ -200,6 +165,3 @@ RtpTimer posix_timer={	0,
 							
 
 #endif // _WIN32
-#endif // BUILD_SCHEDULER
-						
-						
