@@ -21,18 +21,11 @@
 #ifndef RTPMOD_H
 #define RTPMOD_H
 
-#include "rtpport.h"
-
-#ifndef TARGET_IS_HPUXKERNEL
-#include "str_utils.h"
-#else
-#include <sys/stream.h>
-#endif
-
-#include "rtp.h"
+#include <ortp/rtpport.h>
+#include <ortp/str_utils.h>
+#include <ortp/rtp.h>
 
 void rtp_putq(queue_t *q, mblk_t *mp);
-mblk_t *rtp_getq(queue_t *q,guint32 timestamp);
+mblk_t *rtp_getq(queue_t *q,guint32 timestamp, int *rejected);
 
 #endif
-
