@@ -17,12 +17,19 @@
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
 
-#include "rtpport.h"
+#include <ortp/rtpport.h>
+#include <ortp/rtp.h>
+#include <ortp/str_utils.h>
 
-#ifndef TARGET_IS_HPUXKERNEL
+#include <stdio.h>
 
-#include "rtp.h"
-#include "str_utils.h"
+void qinit(queue_t *q){
+	mblk_init(&q->_q_first);
+	mblk_init(&q->_q_last);
+	q->_q_first.b_next=&q->_q_last;
+	q->_q_last.b_prev=&q->_q_first;
+	q->q_mcount=0;
+}
 
 void mblk_init(mblk_t *mp)
 {
@@ -45,12 +52,35 @@ mblk_t *allocb(int size, int pri)
 	datab->db_base=buf;
 	datab->db_lim=buf+size;
 	datab->ref_count=1;
+	datab->db_freefn=g_free;
 	
 	mp->b_datap=datab;
 	mp->b_rptr=mp->b_wptr=buf;
 	mp->b_next=mp->b_prev=mp->b_cont=NULL;
 	return mp;
 }
+
+mblk_t *allocb_with_buf(char *buf, int size, int pri, void (*freefn)(void*) )
+{
+	mblk_t *mp;
+	dblk_t *datab;
+	
+	mp=g_malloc(sizeof(mblk_t));
+	mblk_init(mp);
+	datab=g_malloc(sizeof(dblk_t));
+	
+
+	datab->db_base=buf;
+	datab->db_lim=buf+size;
+	datab->ref_count=1;
+	datab->db_freefn=freefn;
+	
+	mp->b_datap=datab;
+	mp->b_rptr=mp->b_wptr=buf;
+	mp->b_next=mp->b_prev=mp->b_cont=NULL;
+	return mp;
+}
+
 	
 void freeb(mblk_t *mp)
 {
@@ -60,7 +90,8 @@ void freeb(mblk_t *mp)
 	mp->b_datap->ref_count--;
 	if (mp->b_datap->ref_count==0)
 	{
-		g_free(mp->b_datap->db_base);
+		if (mp->b_datap->db_freefn!=NULL)
+			mp->b_datap->db_freefn(mp->b_datap->db_base);
 		g_free(mp->b_datap);
 	}
 	g_free(mp);
@@ -110,63 +141,46 @@ mblk_t	*dupmsg(mblk_t* m)
 
 void putq(queue_t *q,mblk_t *mp)
 {
-	mblk_t *oldlast=q->q_last;
-	g_return_if_fail(mp!=NULL);
-	q->q_last=mp;
-	mp->b_prev=oldlast;
-	mp->b_next=NULL;
-	if (oldlast!=NULL) oldlast->b_next=mp;
-	else q->q_first=mp;
+	q->_q_last.b_prev->b_next=mp;
+	mp->b_prev=q->_q_last.b_prev;
+	mp->b_next=&q->_q_last;
+	q->_q_last.b_prev=mp;
 	q->q_mcount++;
 }
 
 mblk_t *getq(queue_t *q)
 {
-	mblk_t *oldfirst;
-	oldfirst=q->q_first;
-	if (oldfirst==NULL) return NULL;  /* empty queue */
-	
-	q->q_first=oldfirst->b_next;
-	if (oldfirst->b_next!=NULL)
-	{
-		oldfirst->b_next->b_prev=NULL;
-	}
-	else
-	{	/* it was the only element of the q */
-		q->q_last=NULL;
-	}
-	oldfirst->b_prev=oldfirst->b_next=NULL;
+	mblk_t *tmp;
+	tmp=q->_q_first.b_next;
+	if (tmp==&q->_q_last) return NULL;
+	q->_q_first.b_next=tmp->b_next;
+	tmp->b_next->b_prev=&q->_q_first;
+	tmp->b_prev=NULL;
+	tmp->b_next=NULL;
 	q->q_mcount--;
-	return oldfirst;
+	return tmp;
 }
 
 /* insert mp in q just before emp */
 void insq(queue_t *q,mblk_t *emp, mblk_t *mp)
 {
-	mblk_t *m;
-	
-	g_return_if_fail(mp!=NULL);
+	if (emp==NULL){
+		putq(q,mp);
+		return;
+	}
 	q->q_mcount++;
-	if (q->q_first==NULL) {
-		q->q_first=q->q_last=mp;
-	    return;
-	}
-	if (emp==NULL){ /* insert it at the bottom of the q */
-		m=q->q_last;
-		q->q_last=mp;
-		mp->b_prev=m;
-		m->b_next=mp;
-	}
-	else
-	{
-		m=emp->b_prev;
-		mp->b_prev=m;
-		mp->b_next=emp;
-		emp->b_prev=mp;
-		if (m!=NULL){
-			m->b_next=mp;
-		} else q->q_first=mp;
-	}
+	emp->b_prev->b_next=mp;
+	mp->b_prev=emp->b_prev;
+	emp->b_prev=mp;
+	mp->b_next=emp;	
+}
+
+void remq(queue_t *q, mblk_t *mp){
+	q->q_mcount--;
+	mp->b_prev->b_next=mp->b_next;
+	mp->b_next->b_prev=mp->b_prev;
+	mp->b_next=NULL;
+	mp->b_prev=NULL;
 }
 
 /* remove and free all messages in the q */
@@ -249,4 +263,35 @@ mblk_t *copymsg(mblk_t *mp)
 	return newm;
 }
 
-#endif
+mblk_t * appendb(mblk_t *mp, const char *data, int size, gboolean pad){
+	gint padcnt=0;
+	int i;
+	if (pad){
+		padcnt= (gint)(4L-( (long)(mp->b_wptr+size) % 4L)) % 4L;
+	}
+	if ((mp->b_wptr + size +padcnt) > (char*)mp->b_datap->db_lim){
+		/* buffer is not large enough: append a new block (with the same size ?)*/
+		int plen=(char*)mp->b_datap->db_lim - (char*) mp->b_datap->db_base;
+		mp->b_cont=allocb(MAX(plen,size),0);
+		mp=mp->b_cont;
+	}
+	if (size) memcpy(mp->b_wptr,data,size);
+	mp->b_wptr+=size;
+	for (i=0;i<padcnt;i++){
+		mp->b_wptr[0]=0;
+		mp->b_wptr++;
+	}
+	return mp;
+}
+
+void msgappend(mblk_t *mp, const char *data, int size, gboolean pad){
+	while(mp->b_cont!=NULL) mp=mp->b_cont;
+	appendb(mp,data,size,pad);
+}
+
+mblk_t *concatb(mblk_t *mp, mblk_t *newm){
+	while (mp->b_cont!=NULL) mp=mp->b_cont;
+	mp->b_cont=newm;
+	while(newm->b_cont!=NULL) newm=newm->b_cont;
+	return newm;
+}
