@@ -17,7 +17,7 @@
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
 
-#include "telephonyevents.h"
+#include <ortp/telephonyevents.h>
 
 
 PayloadType	telephone_event={
@@ -44,11 +44,8 @@ PayloadType	telephone_event={
 **/
 gint rtp_session_telephone_events_supported(RtpSession *session)
 {
-	if (session->telephone_events_pt==-1)
-	{
-		/* search for a telephony event payload in the current profile */
-		session->telephone_events_pt=rtp_profile_get_payload_number_from_mime(session->profile,"telephone-event");
-	}
+	/* search for a telephony event payload in the current profile */
+	session->telephone_events_pt=rtp_profile_get_payload_number_from_mime(session->profile,"telephone-event");
 	return session->telephone_events_pt;
 }
 
@@ -81,7 +78,7 @@ mblk_t	*rtp_session_create_telephone_event_packet(RtpSession *session, int start
 	rtp->padbit = 0;
 	rtp->extbit = 0;
 	rtp->cc = 0;
-	rtp->ssrc = session->ssrc;
+	rtp->ssrc = session->send_ssrc;
 	/* timestamp set later, when packet is sended */
 	/*seq number set later, when packet is sended */
 	
@@ -118,7 +115,7 @@ gint rtp_session_add_telephone_event(RtpSession *session,
 	/* find the place where to add the new telephony event to the packet */
 	while(mp->b_cont!=NULL) mp=mp->b_cont;
 	/* see if we need to allocate a new mblk_t */
-	if ( (gint)mp->b_wptr >= (gint) mp->b_datap->db_lim){
+	if ( (long)mp->b_wptr >= (long) mp->b_datap->db_lim){
 		mblk_t *newm=allocb(TELEPHONY_EVENTS_ALLOCATED_SIZE,BPRI_MED);
 		mp->b_cont=newm;
 		mp=mp->b_cont;
@@ -301,7 +298,7 @@ void rtp_session_check_telephone_events(RtpSession *session, mblk_t *m0)
 					if (evbuf[i].E==0){
 						evbuf[i].E=1;
 						/* this is a end of event, report it */
-						rtp_signal_table_emit2(&session->on_telephone_event,(gpointer)(gint)events[i].event);
+						rtp_signal_table_emit2(&session->on_telephone_event,(gpointer)(long)events[i].event);
 					}
 				}
 			}
@@ -328,11 +325,9 @@ void rtp_session_check_telephone_events(RtpSession *session, mblk_t *m0)
 			if (events[i].E==1)
 			{
 				
-				rtp_signal_table_emit2(&session->on_telephone_event,(gpointer)(gint)events[i].event);
+				rtp_signal_table_emit2(&session->on_telephone_event,(gpointer)(long)events[i].event);
 				
 			}
 		}
 	}
 }
-
-
